/* Automatically @generated by tree-sitter */

#include "tree_sitter/parser.h"

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#define LANGUAGE_VERSION 15
#define STATE_COUNT 177
#define LARGE_STATE_COUNT 2
#define SYMBOL_COUNT 88
#define ALIAS_COUNT 0
#define TOKEN_COUNT 42
#define EXTERNAL_TOKEN_COUNT 0
#define FIELD_COUNT 16
#define MAX_ALIAS_SEQUENCE_LENGTH 5
#define MAX_RESERVED_WORD_SET_SIZE 0
#define PRODUCTION_ID_COUNT 29
#define SUPERTYPE_COUNT 0

enum ts_symbol_identifiers {
  anon_sym_LBRACK = 1,
  anon_sym_PIPE = 2,
  anon_sym_RBRACK = 3,
  anon_sym_COMMA = 4,
  anon_sym_AT = 5,
  anon_sym_LPAREN = 6,
  anon_sym_RPAREN = 7,
  anon_sym_AT_AT = 8,
  anon_sym_COLON = 9,
  anon_sym_COLON_COLON = 10,
  anon_sym_LBRACE = 11,
  anon_sym_RBRACE = 12,
  sym_symbol = 13,
  anon_sym_DOT_DOT = 14,
  anon_sym_DOT_DOT_DOT = 15,
  anon_sym_true = 16,
  anon_sym_false = 17,
  sym_integer = 18,
  sym_decimal = 19,
  sym_hexadecimal = 20,
  sym_octal = 21,
  sym_measurement = 22,
  anon_sym_SQUOTE = 23,
  sym__single_quoted_text = 24,
  anon_sym_DQUOTE = 25,
  sym__double_quoted_text = 26,
  anon_sym_BQUOTE = 27,
  sym__backticked_text = 28,
  anon_sym_BQUOTE_BQUOTE_BQUOTE = 29,
  anon_sym_LF = 30,
  sym__fenced_string_content = 31,
  anon_sym_DASH = 32,
  anon_sym_EQ = 33,
  anon_sym_TILDE = 34,
  anon_sym_DASH_GT = 35,
  anon_sym_EQ_GT = 36,
  anon_sym_TILDE_GT = 37,
  anon_sym_LT_DASH = 38,
  anon_sym_LT_EQ = 39,
  anon_sym_LT_TILDE = 40,
  sym_comment = 41,
  sym_gram_pattern = 42,
  sym__top_level_pattern = 43,
  sym_annotated_pattern = 44,
  sym_subject_pattern = 45,
  sym_subject_pattern_elements = 46,
  sym__subject_pattern_element = 47,
  sym_annotations = 48,
  sym_property_annotation = 49,
  sym_identified_annotation = 50,
  sym__path_pattern = 51,
  sym_node_pattern = 52,
  sym_relationship_pattern = 53,
  sym_pattern_reference = 54,
  sym__identifier = 55,
  sym__subject = 56,
  sym__value = 57,
  sym__scalar_value = 58,
  sym_array = 59,
  sym_labels = 60,
  sym__label = 61,
  sym_record = 62,
  sym_record_property = 63,
  sym_map = 64,
  sym_map_entry = 65,
  sym_range = 66,
  sym_boolean_literal = 67,
  sym__numeric_literal = 68,
  sym_string_literal = 69,
  sym__single_quoted_string = 70,
  sym__double_quoted_string = 71,
  sym__backticked_string = 72,
  sym__fenced_string = 73,
  sym__fenced_string_body = 74,
  sym_tagged_string = 75,
  sym__relationship_kind = 76,
  sym_undirected_arrow = 77,
  sym_right_arrow = 78,
  sym_left_arrow = 79,
  sym_bidirectional_arrow = 80,
  aux_sym_gram_pattern_repeat1 = 81,
  aux_sym_subject_pattern_elements_repeat1 = 82,
  aux_sym_annotations_repeat1 = 83,
  aux_sym_array_repeat1 = 84,
  aux_sym_labels_repeat1 = 85,
  aux_sym_record_repeat1 = 86,
  aux_sym_map_repeat1 = 87,
};

static const char * const ts_symbol_names[] = {
  [ts_builtin_sym_end] = "end",
  [anon_sym_LBRACK] = "[",
  [anon_sym_PIPE] = "|",
  [anon_sym_RBRACK] = "]",
  [anon_sym_COMMA] = ",",
  [anon_sym_AT] = "@",
  [anon_sym_LPAREN] = "(",
  [anon_sym_RPAREN] = ")",
  [anon_sym_AT_AT] = "@@",
  [anon_sym_COLON] = ":",
  [anon_sym_COLON_COLON] = "::",
  [anon_sym_LBRACE] = "{",
  [anon_sym_RBRACE] = "}",
  [sym_symbol] = "symbol",
  [anon_sym_DOT_DOT] = "..",
  [anon_sym_DOT_DOT_DOT] = "...",
  [anon_sym_true] = "true",
  [anon_sym_false] = "false",
  [sym_integer] = "integer",
  [sym_decimal] = "decimal",
  [sym_hexadecimal] = "hexadecimal",
  [sym_octal] = "octal",
  [sym_measurement] = "measurement",
  [anon_sym_SQUOTE] = "'",
  [sym__single_quoted_text] = "string_content",
  [anon_sym_DQUOTE] = "\"",
  [sym__double_quoted_text] = "string_content",
  [anon_sym_BQUOTE] = "`",
  [sym__backticked_text] = "string_content",
  [anon_sym_BQUOTE_BQUOTE_BQUOTE] = "```",
  [anon_sym_LF] = "\n",
  [sym__fenced_string_content] = "string_content",
  [anon_sym_DASH] = "-",
  [anon_sym_EQ] = "=",
  [anon_sym_TILDE] = "~",
  [anon_sym_DASH_GT] = "->",
  [anon_sym_EQ_GT] = "=>",
  [anon_sym_TILDE_GT] = "~>",
  [anon_sym_LT_DASH] = "<-",
  [anon_sym_LT_EQ] = "<=",
  [anon_sym_LT_TILDE] = "<~",
  [sym_comment] = "comment",
  [sym_gram_pattern] = "gram_pattern",
  [sym__top_level_pattern] = "_top_level_pattern",
  [sym_annotated_pattern] = "annotated_pattern",
  [sym_subject_pattern] = "subject_pattern",
  [sym_subject_pattern_elements] = "subject_pattern_elements",
  [sym__subject_pattern_element] = "_subject_pattern_element",
  [sym_annotations] = "annotations",
  [sym_property_annotation] = "property_annotation",
  [sym_identified_annotation] = "identified_annotation",
  [sym__path_pattern] = "_path_pattern",
  [sym_node_pattern] = "node_pattern",
  [sym_relationship_pattern] = "relationship_pattern",
  [sym_pattern_reference] = "pattern_reference",
  [sym__identifier] = "_identifier",
  [sym__subject] = "_subject",
  [sym__value] = "_value",
  [sym__scalar_value] = "_scalar_value",
  [sym_array] = "array",
  [sym_labels] = "labels",
  [sym__label] = "_label",
  [sym_record] = "record",
  [sym_record_property] = "record_property",
  [sym_map] = "map",
  [sym_map_entry] = "map_entry",
  [sym_range] = "range",
  [sym_boolean_literal] = "boolean_literal",
  [sym__numeric_literal] = "_numeric_literal",
  [sym_string_literal] = "string_literal",
  [sym__single_quoted_string] = "_single_quoted_string",
  [sym__double_quoted_string] = "_double_quoted_string",
  [sym__backticked_string] = "_backticked_string",
  [sym__fenced_string] = "_fenced_string",
  [sym__fenced_string_body] = "_fenced_string_body",
  [sym_tagged_string] = "tagged_string",
  [sym__relationship_kind] = "_relationship_kind",
  [sym_undirected_arrow] = "undirected_arrow",
  [sym_right_arrow] = "right_arrow",
  [sym_left_arrow] = "left_arrow",
  [sym_bidirectional_arrow] = "bidirectional_arrow",
  [aux_sym_gram_pattern_repeat1] = "gram_pattern_repeat1",
  [aux_sym_subject_pattern_elements_repeat1] = "subject_pattern_elements_repeat1",
  [aux_sym_annotations_repeat1] = "annotations_repeat1",
  [aux_sym_array_repeat1] = "array_repeat1",
  [aux_sym_labels_repeat1] = "labels_repeat1",
  [aux_sym_record_repeat1] = "record_repeat1",
  [aux_sym_map_repeat1] = "map_repeat1",
};

static const TSSymbol ts_symbol_map[] = {
  [ts_builtin_sym_end] = ts_builtin_sym_end,
  [anon_sym_LBRACK] = anon_sym_LBRACK,
  [anon_sym_PIPE] = anon_sym_PIPE,
  [anon_sym_RBRACK] = anon_sym_RBRACK,
  [anon_sym_COMMA] = anon_sym_COMMA,
  [anon_sym_AT] = anon_sym_AT,
  [anon_sym_LPAREN] = anon_sym_LPAREN,
  [anon_sym_RPAREN] = anon_sym_RPAREN,
  [anon_sym_AT_AT] = anon_sym_AT_AT,
  [anon_sym_COLON] = anon_sym_COLON,
  [anon_sym_COLON_COLON] = anon_sym_COLON_COLON,
  [anon_sym_LBRACE] = anon_sym_LBRACE,
  [anon_sym_RBRACE] = anon_sym_RBRACE,
  [sym_symbol] = sym_symbol,
  [anon_sym_DOT_DOT] = anon_sym_DOT_DOT,
  [anon_sym_DOT_DOT_DOT] = anon_sym_DOT_DOT_DOT,
  [anon_sym_true] = anon_sym_true,
  [anon_sym_false] = anon_sym_false,
  [sym_integer] = sym_integer,
  [sym_decimal] = sym_decimal,
  [sym_hexadecimal] = sym_hexadecimal,
  [sym_octal] = sym_octal,
  [sym_measurement] = sym_measurement,
  [anon_sym_SQUOTE] = anon_sym_SQUOTE,
  [sym__single_quoted_text] = sym__single_quoted_text,
  [anon_sym_DQUOTE] = anon_sym_DQUOTE,
  [sym__double_quoted_text] = sym__single_quoted_text,
  [anon_sym_BQUOTE] = anon_sym_BQUOTE,
  [sym__backticked_text] = sym__single_quoted_text,
  [anon_sym_BQUOTE_BQUOTE_BQUOTE] = anon_sym_BQUOTE_BQUOTE_BQUOTE,
  [anon_sym_LF] = anon_sym_LF,
  [sym__fenced_string_content] = sym__single_quoted_text,
  [anon_sym_DASH] = anon_sym_DASH,
  [anon_sym_EQ] = anon_sym_EQ,
  [anon_sym_TILDE] = anon_sym_TILDE,
  [anon_sym_DASH_GT] = anon_sym_DASH_GT,
  [anon_sym_EQ_GT] = anon_sym_EQ_GT,
  [anon_sym_TILDE_GT] = anon_sym_TILDE_GT,
  [anon_sym_LT_DASH] = anon_sym_LT_DASH,
  [anon_sym_LT_EQ] = anon_sym_LT_EQ,
  [anon_sym_LT_TILDE] = anon_sym_LT_TILDE,
  [sym_comment] = sym_comment,
  [sym_gram_pattern] = sym_gram_pattern,
  [sym__top_level_pattern] = sym__top_level_pattern,
  [sym_annotated_pattern] = sym_annotated_pattern,
  [sym_subject_pattern] = sym_subject_pattern,
  [sym_subject_pattern_elements] = sym_subject_pattern_elements,
  [sym__subject_pattern_element] = sym__subject_pattern_element,
  [sym_annotations] = sym_annotations,
  [sym_property_annotation] = sym_property_annotation,
  [sym_identified_annotation] = sym_identified_annotation,
  [sym__path_pattern] = sym__path_pattern,
  [sym_node_pattern] = sym_node_pattern,
  [sym_relationship_pattern] = sym_relationship_pattern,
  [sym_pattern_reference] = sym_pattern_reference,
  [sym__identifier] = sym__identifier,
  [sym__subject] = sym__subject,
  [sym__value] = sym__value,
  [sym__scalar_value] = sym__scalar_value,
  [sym_array] = sym_array,
  [sym_labels] = sym_labels,
  [sym__label] = sym__label,
  [sym_record] = sym_record,
  [sym_record_property] = sym_record_property,
  [sym_map] = sym_map,
  [sym_map_entry] = sym_map_entry,
  [sym_range] = sym_range,
  [sym_boolean_literal] = sym_boolean_literal,
  [sym__numeric_literal] = sym__numeric_literal,
  [sym_string_literal] = sym_string_literal,
  [sym__single_quoted_string] = sym__single_quoted_string,
  [sym__double_quoted_string] = sym__double_quoted_string,
  [sym__backticked_string] = sym__backticked_string,
  [sym__fenced_string] = sym__fenced_string,
  [sym__fenced_string_body] = sym__fenced_string_body,
  [sym_tagged_string] = sym_tagged_string,
  [sym__relationship_kind] = sym__relationship_kind,
  [sym_undirected_arrow] = sym_undirected_arrow,
  [sym_right_arrow] = sym_right_arrow,
  [sym_left_arrow] = sym_left_arrow,
  [sym_bidirectional_arrow] = sym_bidirectional_arrow,
  [aux_sym_gram_pattern_repeat1] = aux_sym_gram_pattern_repeat1,
  [aux_sym_subject_pattern_elements_repeat1] = aux_sym_subject_pattern_elements_repeat1,
  [aux_sym_annotations_repeat1] = aux_sym_annotations_repeat1,
  [aux_sym_array_repeat1] = aux_sym_array_repeat1,
  [aux_sym_labels_repeat1] = aux_sym_labels_repeat1,
  [aux_sym_record_repeat1] = aux_sym_record_repeat1,
  [aux_sym_map_repeat1] = aux_sym_map_repeat1,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
  [ts_builtin_sym_end] = {
    .visible = false,
    .named = true,
  },
  [anon_sym_LBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COMMA] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AT_AT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [sym_symbol] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_DOT_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_DOT_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_true] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_false] = {
    .visible = true,
    .named = false,
  },
  [sym_integer] = {
    .visible = true,
    .named = true,
  },
  [sym_decimal] = {
    .visible = true,
    .named = true,
  },
  [sym_hexadecimal] = {
    .visible = true,
    .named = true,
  },
  [sym_octal] = {
    .visible = true,
    .named = true,
  },
  [sym_measurement] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [sym__single_quoted_text] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [sym__double_quoted_text] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_BQUOTE] = {
    .visible = true,
    .named = false,
  },
  [sym__backticked_text] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_BQUOTE_BQUOTE_BQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LF] = {
    .visible = true,
    .named = false,
  },
  [sym__fenced_string_content] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_TILDE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_TILDE_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_TILDE] = {
    .visible = true,
    .named = false,
  },
  [sym_comment] = {
    .visible = true,
    .named = true,
  },
  [sym_gram_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym__top_level_pattern] = {
    .visible = false,
    .named = true,
  },
  [sym_annotated_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_subject_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_subject_pattern_elements] = {
    .visible = true,
    .named = true,
  },
  [sym__subject_pattern_element] = {
    .visible = false,
    .named = true,
  },
  [sym_annotations] = {
    .visible = true,
    .named = true,
  },
  [sym_property_annotation] = {
    .visible = true,
    .named = true,
  },
  [sym_identified_annotation] = {
    .visible = true,
    .named = true,
  },
  [sym__path_pattern] = {
    .visible = false,
    .named = true,
  },
  [sym_node_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_relationship_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_pattern_reference] = {
    .visible = true,
    .named = true,
  },
  [sym__identifier] = {
    .visible = false,
    .named = true,
  },
  [sym__subject] = {
    .visible = false,
    .named = true,
  },
  [sym__value] = {
    .visible = false,
    .named = true,
  },
  [sym__scalar_value] = {
    .visible = false,
    .named = true,
  },
  [sym_array] = {
    .visible = true,
    .named = true,
  },
  [sym_labels] = {
    .visible = true,
    .named = true,
  },
  [sym__label] = {
    .visible = false,
    .named = true,
  },
  [sym_record] = {
    .visible = true,
    .named = true,
  },
  [sym_record_property] = {
    .visible = true,
    .named = true,
  },
  [sym_map] = {
    .visible = true,
    .named = true,
  },
  [sym_map_entry] = {
    .visible = true,
    .named = true,
  },
  [sym_range] = {
    .visible = true,
    .named = true,
  },
  [sym_boolean_literal] = {
    .visible = true,
    .named = true,
  },
  [sym__numeric_literal] = {
    .visible = false,
    .named = true,
  },
  [sym_string_literal] = {
    .visible = true,
    .named = true,
  },
  [sym__single_quoted_string] = {
    .visible = false,
    .named = true,
  },
  [sym__double_quoted_string] = {
    .visible = false,
    .named = true,
  },
  [sym__backticked_string] = {
    .visible = false,
    .named = true,
  },
  [sym__fenced_string] = {
    .visible = false,
    .named = true,
  },
  [sym__fenced_string_body] = {
    .visible = false,
    .named = true,
  },
  [sym_tagged_string] = {
    .visible = true,
    .named = true,
  },
  [sym__relationship_kind] = {
    .visible = false,
    .named = true,
  },
  [sym_undirected_arrow] = {
    .visible = true,
    .named = true,
  },
  [sym_right_arrow] = {
    .visible = true,
    .named = true,
  },
  [sym_left_arrow] = {
    .visible = true,
    .named = true,
  },
  [sym_bidirectional_arrow] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_gram_pattern_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_subject_pattern_elements_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_annotations_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_array_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_labels_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_record_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_map_repeat1] = {
    .visible = false,
    .named = false,
  },
};

enum ts_field_identifiers {
  field_annotations = 1,
  field_content = 2,
  field_elements = 3,
  field_identifier = 4,
  field_key = 5,
  field_kind = 6,
  field_labels = 7,
  field_left = 8,
  field_lower = 9,
  field_record = 10,
  field_right = 11,
  field_root = 12,
  field_subject = 13,
  field_tag = 14,
  field_upper = 15,
  field_value = 16,
};

static const char * const ts_field_names[] = {
  [0] = NULL,
  [field_annotations] = "annotations",
  [field_content] = "content",
  [field_elements] = "elements",
  [field_identifier] = "identifier",
  [field_key] = "key",
  [field_kind] = "kind",
  [field_labels] = "labels",
  [field_left] = "left",
  [field_lower] = "lower",
  [field_record] = "record",
  [field_right] = "right",
  [field_root] = "root",
  [field_subject] = "subject",
  [field_tag] = "tag",
  [field_upper] = "upper",
  [field_value] = "value",
};

static const TSMapSlice ts_field_map_slices[PRODUCTION_ID_COUNT] = {
  [1] = {.index = 0, .length = 1},
  [2] = {.index = 1, .length = 1},
  [3] = {.index = 2, .length = 1},
  [4] = {.index = 3, .length = 1},
  [5] = {.index = 4, .length = 1},
  [6] = {.index = 5, .length = 1},
  [7] = {.index = 6, .length = 1},
  [8] = {.index = 7, .length = 2},
  [9] = {.index = 9, .length = 1},
  [10] = {.index = 10, .length = 2},
  [11] = {.index = 12, .length = 2},
  [12] = {.index = 14, .length = 4},
  [13] = {.index = 18, .length = 2},
  [14] = {.index = 20, .length = 2},
  [15] = {.index = 22, .length = 3},
  [16] = {.index = 25, .length = 2},
  [17] = {.index = 27, .length = 1},
  [18] = {.index = 28, .length = 3},
  [19] = {.index = 31, .length = 2},
  [20] = {.index = 33, .length = 6},
  [21] = {.index = 39, .length = 1},
  [22] = {.index = 40, .length = 2},
  [23] = {.index = 42, .length = 1},
  [24] = {.index = 43, .length = 2},
  [25] = {.index = 45, .length = 4},
  [26] = {.index = 49, .length = 2},
  [27] = {.index = 51, .length = 1},
  [28] = {.index = 52, .length = 2},
};

static const TSFieldMapEntry ts_field_map_entries[] = {
  [0] =
    {field_root, 0},
  [1] =
    {field_identifier, 0},
  [2] =
    {field_labels, 0},
  [3] =
    {field_record, 0},
  [4] =
    {field_content, 0, .inherited = true},
  [5] =
    {field_identifier, 1},
  [6] =
    {field_labels, 1},
  [7] =
    {field_annotations, 0},
    {field_elements, 1},
  [9] =
    {field_content, 1, .inherited = true},
  [10] =
    {field_identifier, 0},
    {field_labels, 1},
  [12] =
    {field_identifier, 0},
    {field_record, 1},
  [14] =
    {field_identifier, 1, .inherited = true},
    {field_labels, 1, .inherited = true},
    {field_record, 1, .inherited = true},
    {field_subject, 1},
  [18] =
    {field_labels, 0},
    {field_record, 1},
  [20] =
    {field_identifier, 1},
    {field_labels, 2},
  [22] =
    {field_kind, 1},
    {field_left, 0},
    {field_right, 2},
  [25] =
    {field_elements, 1},
    {field_elements, 2},
  [27] =
    {field_content, 1},
  [28] =
    {field_identifier, 0},
    {field_labels, 1},
    {field_record, 2},
  [31] =
    {field_key, 0},
    {field_value, 2},
  [33] =
    {field_elements, 2},
    {field_elements, 3},
    {field_identifier, 1, .inherited = true},
    {field_labels, 1, .inherited = true},
    {field_record, 1, .inherited = true},
    {field_subject, 1},
  [39] =
    {field_upper, 1},
  [40] =
    {field_key, 1},
    {field_value, 3},
  [42] =
    {field_lower, 0},
  [43] =
    {field_lower, 0},
    {field_upper, 2},
  [45] =
    {field_identifier, 2, .inherited = true},
    {field_labels, 2, .inherited = true},
    {field_record, 2, .inherited = true},
    {field_subject, 2},
  [49] =
    {field_content, 2},
    {field_tag, 0},
  [51] =
    {field_tag, 1},
  [52] =
    {field_content, 3},
    {field_tag, 1},
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
  [0] = {0},
};

static const uint16_t ts_non_terminal_alias_map[] = {
  0,
};

static const TSStateId ts_primary_state_ids[STATE_COUNT] = {
  [0] = 0,
  [1] = 1,
  [2] = 2,
  [3] = 3,
  [4] = 4,
  [5] = 5,
  [6] = 6,
  [7] = 7,
  [8] = 8,
  [9] = 9,
  [10] = 10,
  [11] = 11,
  [12] = 12,
  [13] = 13,
  [14] = 14,
  [15] = 15,
  [16] = 16,
  [17] = 17,
  [18] = 18,
  [19] = 19,
  [20] = 20,
  [21] = 21,
  [22] = 22,
  [23] = 23,
  [24] = 24,
  [25] = 25,
  [26] = 26,
  [27] = 27,
  [28] = 28,
  [29] = 29,
  [30] = 30,
  [31] = 31,
  [32] = 32,
  [33] = 33,
  [34] = 34,
  [35] = 35,
  [36] = 36,
  [37] = 37,
  [38] = 38,
  [39] = 39,
  [40] = 40,
  [41] = 41,
  [42] = 42,
  [43] = 43,
  [44] = 44,
  [45] = 45,
  [46] = 46,
  [47] = 47,
  [48] = 48,
  [49] = 49,
  [50] = 50,
  [51] = 51,
  [52] = 52,
  [53] = 53,
  [54] = 54,
  [55] = 55,
  [56] = 56,
  [57] = 57,
  [58] = 58,
  [59] = 59,
  [60] = 60,
  [61] = 61,
  [62] = 62,
  [63] = 63,
  [64] = 64,
  [65] = 65,
  [66] = 66,
  [67] = 67,
  [68] = 68,
  [69] = 69,
  [70] = 70,
  [71] = 71,
  [72] = 72,
  [73] = 73,
  [74] = 74,
  [75] = 75,
  [76] = 76,
  [77] = 77,
  [78] = 78,
  [79] = 79,
  [80] = 80,
  [81] = 81,
  [82] = 82,
  [83] = 83,
  [84] = 84,
  [85] = 85,
  [86] = 86,
  [87] = 87,
  [88] = 88,
  [89] = 89,
  [90] = 90,
  [91] = 91,
  [92] = 92,
  [93] = 93,
  [94] = 94,
  [95] = 95,
  [96] = 96,
  [97] = 97,
  [98] = 98,
  [99] = 99,
  [100] = 100,
  [101] = 101,
  [102] = 102,
  [103] = 103,
  [104] = 104,
  [105] = 105,
  [106] = 106,
  [107] = 107,
  [108] = 108,
  [109] = 109,
  [110] = 110,
  [111] = 111,
  [112] = 112,
  [113] = 113,
  [114] = 114,
  [115] = 115,
  [116] = 116,
  [117] = 117,
  [118] = 118,
  [119] = 119,
  [120] = 120,
  [121] = 121,
  [122] = 122,
  [123] = 123,
  [124] = 124,
  [125] = 125,
  [126] = 126,
  [127] = 127,
  [128] = 128,
  [129] = 129,
  [130] = 130,
  [131] = 131,
  [132] = 132,
  [133] = 133,
  [134] = 134,
  [135] = 135,
  [136] = 136,
  [137] = 137,
  [138] = 138,
  [139] = 139,
  [140] = 140,
  [141] = 141,
  [142] = 142,
  [143] = 143,
  [144] = 144,
  [145] = 145,
  [146] = 146,
  [147] = 147,
  [148] = 148,
  [149] = 149,
  [150] = 150,
  [151] = 151,
  [152] = 152,
  [153] = 153,
  [154] = 154,
  [155] = 155,
  [156] = 156,
  [157] = 157,
  [158] = 158,
  [159] = 159,
  [160] = 160,
  [161] = 161,
  [162] = 162,
  [163] = 163,
  [164] = 164,
  [165] = 165,
  [166] = 166,
  [167] = 167,
  [168] = 168,
  [169] = 169,
  [170] = 170,
  [171] = 171,
  [172] = 172,
  [173] = 173,
  [174] = 174,
  [175] = 175,
  [176] = 176,
};

static bool ts_lex(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (eof) ADVANCE(22);
      ADVANCE_MAP(
        '"', 63,
        '\'', 58,
        '(', 28,
        ')', 29,
        ',', 26,
        '-', 79,
        '.', 5,
        '/', 8,
        '0', 48,
        ':', 31,
        '<', 4,
        '=', 82,
        '@', 27,
        '[', 23,
        ']', 25,
        '`', 68,
        'f', 35,
        't', 39,
        '{', 33,
        '|', 24,
        '}', 34,
        '~', 84,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(0);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(49);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(42);
      END_STATE();
    case 1:
      if (lookahead == '\n') ADVANCE(74);
      if (lookahead == '/') ADVANCE(8);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(1);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(42);
      END_STATE();
    case 2:
      ADVANCE_MAP(
        '"', 63,
        '\'', 58,
        '(', 28,
        ')', 29,
        '-', 11,
        '/', 8,
        '0', 47,
        ':', 31,
        '[', 23,
        ']', 25,
        '`', 68,
        '{', 33,
        '|', 24,
        '}', 34,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(2);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(51);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(42);
      END_STATE();
    case 3:
      ADVANCE_MAP(
        '"', 63,
        '\'', 58,
        '-', 10,
        '.', 7,
        '/', 8,
        '0', 48,
        '[', 23,
        '`', 68,
        'f', 35,
        't', 39,
        '{', 33,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(3);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(49);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(42);
      END_STATE();
    case 4:
      if (lookahead == '-') ADVANCE(88);
      if (lookahead == '=') ADVANCE(89);
      if (lookahead == '~') ADVANCE(90);
      END_STATE();
    case 5:
      if (lookahead == '.') ADVANCE(43);
      END_STATE();
    case 6:
      if (lookahead == '.') ADVANCE(44);
      END_STATE();
    case 7:
      if (lookahead == '.') ADVANCE(6);
      END_STATE();
    case 8:
      if (lookahead == '/') ADVANCE(96);
      END_STATE();
    case 9:
      if (lookahead == '/') ADVANCE(77);
      if (lookahead == '`') ADVANCE(15);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(76);
      if (lookahead != 0) ADVANCE(78);
      END_STATE();
    case 10:
      if (lookahead == '0') ADVANCE(50);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(49);
      END_STATE();
    case 11:
      if (lookahead == '0') ADVANCE(47);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(51);
      END_STATE();
    case 12:
      if (lookahead == '`') ADVANCE(73);
      END_STATE();
    case 13:
      if (lookahead == '`') ADVANCE(73);
      if (lookahead != 0) ADVANCE(78);
      END_STATE();
    case 14:
      if (lookahead == '`') ADVANCE(20);
      if (lookahead != 0) ADVANCE(78);
      END_STATE();
    case 15:
      if (lookahead == '`') ADVANCE(13);
      if (lookahead != 0) ADVANCE(78);
      END_STATE();
    case 16:
      ADVANCE_MAP(
        '"', 67,
        '/', 67,
        '\\', 67,
        'b', 67,
        'f', 67,
        'n', 67,
        'r', 67,
        't', 67,
      );
      END_STATE();
    case 17:
      ADVANCE_MAP(
        '\'', 62,
        '/', 62,
        '\\', 62,
        'b', 62,
        'f', 62,
        'n', 62,
        'r', 62,
        't', 62,
      );
      END_STATE();
    case 18:
      ADVANCE_MAP(
        '/', 71,
        '\\', 71,
        '`', 71,
        'b', 71,
        'f', 71,
        'n', 71,
        'r', 71,
        't', 71,
      );
      END_STATE();
    case 19:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(52);
      END_STATE();
    case 20:
      if (lookahead != 0 &&
          lookahead != '`') ADVANCE(78);
      END_STATE();
    case 21:
      if (eof) ADVANCE(22);
      ADVANCE_MAP(
        '(', 28,
        ',', 26,
        '-', 80,
        '/', 8,
        '<', 4,
        '=', 81,
        '@', 27,
        '[', 23,
        ']', 25,
        '~', 83,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(21);
      END_STATE();
    case 22:
      ACCEPT_TOKEN(ts_builtin_sym_end);
      END_STATE();
    case 23:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      END_STATE();
    case 24:
      ACCEPT_TOKEN(anon_sym_PIPE);
      END_STATE();
    case 25:
      ACCEPT_TOKEN(anon_sym_RBRACK);
      END_STATE();
    case 26:
      ACCEPT_TOKEN(anon_sym_COMMA);
      END_STATE();
    case 27:
      ACCEPT_TOKEN(anon_sym_AT);
      if (lookahead == '@') ADVANCE(30);
      END_STATE();
    case 28:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      END_STATE();
    case 29:
      ACCEPT_TOKEN(anon_sym_RPAREN);
      END_STATE();
    case 30:
      ACCEPT_TOKEN(anon_sym_AT_AT);
      END_STATE();
    case 31:
      ACCEPT_TOKEN(anon_sym_COLON);
      if (lookahead == ':') ADVANCE(32);
      END_STATE();
    case 32:
      ACCEPT_TOKEN(anon_sym_COLON_COLON);
      END_STATE();
    case 33:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      END_STATE();
    case 34:
      ACCEPT_TOKEN(anon_sym_RBRACE);
      END_STATE();
    case 35:
      ACCEPT_TOKEN(sym_symbol);
      if (lookahead == 'a') ADVANCE(38);
      if (lookahead == '-' ||
          lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(42);
      END_STATE();
    case 36:
      ACCEPT_TOKEN(sym_symbol);
      if (lookahead == 'e') ADVANCE(45);
      if (lookahead == '-' ||
          lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(42);
      END_STATE();
    case 37:
      ACCEPT_TOKEN(sym_symbol);
      if (lookahead == 'e') ADVANCE(46);
      if (lookahead == '-' ||
          lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(42);
      END_STATE();
    case 38:
      ACCEPT_TOKEN(sym_symbol);
      if (lookahead == 'l') ADVANCE(40);
      if (lookahead == '-' ||
          lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(42);
      END_STATE();
    case 39:
      ACCEPT_TOKEN(sym_symbol);
      if (lookahead == 'r') ADVANCE(41);
      if (lookahead == '-' ||
          lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(42);
      END_STATE();
    case 40:
      ACCEPT_TOKEN(sym_symbol);
      if (lookahead == 's') ADVANCE(37);
      if (lookahead == '-' ||
          lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(42);
      END_STATE();
    case 41:
      ACCEPT_TOKEN(sym_symbol);
      if (lookahead == 'u') ADVANCE(36);
      if (lookahead == '-' ||
          lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(42);
      END_STATE();
    case 42:
      ACCEPT_TOKEN(sym_symbol);
      if (lookahead == '-' ||
          lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(42);
      END_STATE();
    case 43:
      ACCEPT_TOKEN(anon_sym_DOT_DOT);
      if (lookahead == '.') ADVANCE(44);
      END_STATE();
    case 44:
      ACCEPT_TOKEN(anon_sym_DOT_DOT_DOT);
      END_STATE();
    case 45:
      ACCEPT_TOKEN(anon_sym_true);
      if (lookahead == '-' ||
          lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(42);
      END_STATE();
    case 46:
      ACCEPT_TOKEN(anon_sym_false);
      if (lookahead == '-' ||
          lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('@' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(42);
      END_STATE();
    case 47:
      ACCEPT_TOKEN(sym_integer);
      END_STATE();
    case 48:
      ACCEPT_TOKEN(sym_integer);
      if (lookahead == '.') ADVANCE(19);
      if (lookahead == 'x') ADVANCE(56);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(55);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(57);
      END_STATE();
    case 49:
      ACCEPT_TOKEN(sym_integer);
      if (lookahead == '.') ADVANCE(19);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(49);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(57);
      END_STATE();
    case 50:
      ACCEPT_TOKEN(sym_integer);
      if (lookahead == '.') ADVANCE(19);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(57);
      END_STATE();
    case 51:
      ACCEPT_TOKEN(sym_integer);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(51);
      END_STATE();
    case 52:
      ACCEPT_TOKEN(sym_decimal);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(52);
      END_STATE();
    case 53:
      ACCEPT_TOKEN(sym_hexadecimal);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(54);
      if (('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(53);
      if (('G' <= lookahead && lookahead <= 'Z') ||
          ('g' <= lookahead && lookahead <= 'z')) ADVANCE(57);
      END_STATE();
    case 54:
      ACCEPT_TOKEN(sym_hexadecimal);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(54);
      END_STATE();
    case 55:
      ACCEPT_TOKEN(sym_octal);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(55);
      END_STATE();
    case 56:
      ACCEPT_TOKEN(sym_measurement);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(54);
      if (('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(53);
      if (('G' <= lookahead && lookahead <= 'Z') ||
          ('g' <= lookahead && lookahead <= 'z')) ADVANCE(57);
      END_STATE();
    case 57:
      ACCEPT_TOKEN(sym_measurement);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(57);
      END_STATE();
    case 58:
      ACCEPT_TOKEN(anon_sym_SQUOTE);
      END_STATE();
    case 59:
      ACCEPT_TOKEN(sym__single_quoted_text);
      if (lookahead == '\'') ADVANCE(96);
      if (lookahead == '\\') ADVANCE(94);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(59);
      END_STATE();
    case 60:
      ACCEPT_TOKEN(sym__single_quoted_text);
      if (lookahead == '/') ADVANCE(61);
      if (lookahead == '\\') ADVANCE(17);
      if (lookahead == '\t' ||
          (0x0b <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(60);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != '\'') ADVANCE(62);
      END_STATE();
    case 61:
      ACCEPT_TOKEN(sym__single_quoted_text);
      if (lookahead == '/') ADVANCE(59);
      if (lookahead == '\\') ADVANCE(17);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\'') ADVANCE(62);
      END_STATE();
    case 62:
      ACCEPT_TOKEN(sym__single_quoted_text);
      if (lookahead == '\\') ADVANCE(17);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\'') ADVANCE(62);
      END_STATE();
    case 63:
      ACCEPT_TOKEN(anon_sym_DQUOTE);
      END_STATE();
    case 64:
      ACCEPT_TOKEN(sym__double_quoted_text);
      if (lookahead == '"') ADVANCE(96);
      if (lookahead == '\\') ADVANCE(93);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(64);
      END_STATE();
    case 65:
      ACCEPT_TOKEN(sym__double_quoted_text);
      if (lookahead == '/') ADVANCE(66);
      if (lookahead == '\\') ADVANCE(16);
      if (lookahead == '\t' ||
          (0x0b <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(65);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != '"') ADVANCE(67);
      END_STATE();
    case 66:
      ACCEPT_TOKEN(sym__double_quoted_text);
      if (lookahead == '/') ADVANCE(64);
      if (lookahead == '\\') ADVANCE(16);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"') ADVANCE(67);
      END_STATE();
    case 67:
      ACCEPT_TOKEN(sym__double_quoted_text);
      if (lookahead == '\\') ADVANCE(16);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"') ADVANCE(67);
      END_STATE();
    case 68:
      ACCEPT_TOKEN(anon_sym_BQUOTE);
      if (lookahead == '`') ADVANCE(12);
      END_STATE();
    case 69:
      ACCEPT_TOKEN(sym__backticked_text);
      if (lookahead == '/') ADVANCE(70);
      if (lookahead == '\\') ADVANCE(18);
      if (lookahead == '\t' ||
          (0x0b <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(69);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != '`') ADVANCE(71);
      END_STATE();
    case 70:
      ACCEPT_TOKEN(sym__backticked_text);
      if (lookahead == '/') ADVANCE(72);
      if (lookahead == '\\') ADVANCE(18);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '`') ADVANCE(71);
      END_STATE();
    case 71:
      ACCEPT_TOKEN(sym__backticked_text);
      if (lookahead == '\\') ADVANCE(18);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '`') ADVANCE(71);
      END_STATE();
    case 72:
      ACCEPT_TOKEN(sym__backticked_text);
      if (lookahead == '\\') ADVANCE(95);
      if (lookahead == '`') ADVANCE(96);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(72);
      END_STATE();
    case 73:
      ACCEPT_TOKEN(anon_sym_BQUOTE_BQUOTE_BQUOTE);
      END_STATE();
    case 74:
      ACCEPT_TOKEN(anon_sym_LF);
      if (lookahead == '\n') ADVANCE(74);
      END_STATE();
    case 75:
      ACCEPT_TOKEN(sym__fenced_string_content);
      if (lookahead == '\n') ADVANCE(78);
      if (lookahead == '`') ADVANCE(92);
      if (lookahead != 0) ADVANCE(75);
      END_STATE();
    case 76:
      ACCEPT_TOKEN(sym__fenced_string_content);
      if (lookahead == '/') ADVANCE(77);
      if (lookahead == '`') ADVANCE(15);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(76);
      if (lookahead != 0) ADVANCE(78);
      END_STATE();
    case 77:
      ACCEPT_TOKEN(sym__fenced_string_content);
      if (lookahead == '/') ADVANCE(75);
      if (lookahead == '`') ADVANCE(14);
      if (lookahead != 0) ADVANCE(78);
      END_STATE();
    case 78:
      ACCEPT_TOKEN(sym__fenced_string_content);
      if (lookahead == '`') ADVANCE(14);
      if (lookahead != 0) ADVANCE(78);
      END_STATE();
    case 79:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '0') ADVANCE(50);
      if (lookahead == '>') ADVANCE(85);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(49);
      END_STATE();
    case 80:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '>') ADVANCE(85);
      END_STATE();
    case 81:
      ACCEPT_TOKEN(anon_sym_EQ);
      END_STATE();
    case 82:
      ACCEPT_TOKEN(anon_sym_EQ);
      if (lookahead == '>') ADVANCE(86);
      END_STATE();
    case 83:
      ACCEPT_TOKEN(anon_sym_TILDE);
      END_STATE();
    case 84:
      ACCEPT_TOKEN(anon_sym_TILDE);
      if (lookahead == '>') ADVANCE(87);
      END_STATE();
    case 85:
      ACCEPT_TOKEN(anon_sym_DASH_GT);
      END_STATE();
    case 86:
      ACCEPT_TOKEN(anon_sym_EQ_GT);
      END_STATE();
    case 87:
      ACCEPT_TOKEN(anon_sym_TILDE_GT);
      END_STATE();
    case 88:
      ACCEPT_TOKEN(anon_sym_LT_DASH);
      END_STATE();
    case 89:
      ACCEPT_TOKEN(anon_sym_LT_EQ);
      END_STATE();
    case 90:
      ACCEPT_TOKEN(anon_sym_LT_TILDE);
      END_STATE();
    case 91:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == '\n') ADVANCE(78);
      if (lookahead == '`') ADVANCE(96);
      if (lookahead != 0) ADVANCE(75);
      END_STATE();
    case 92:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == '\n') ADVANCE(78);
      if (lookahead == '`') ADVANCE(91);
      if (lookahead != 0) ADVANCE(75);
      END_STATE();
    case 93:
      ACCEPT_TOKEN(sym_comment);
      ADVANCE_MAP(
        '"', 64,
        '/', 64,
        '\\', 64,
        'b', 64,
        'f', 64,
        'n', 64,
        'r', 64,
        't', 64,
      );
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(96);
      END_STATE();
    case 94:
      ACCEPT_TOKEN(sym_comment);
      ADVANCE_MAP(
        '\'', 59,
        '/', 59,
        '\\', 59,
        'b', 59,
        'f', 59,
        'n', 59,
        'r', 59,
        't', 59,
      );
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(96);
      END_STATE();
    case 95:
      ACCEPT_TOKEN(sym_comment);
      ADVANCE_MAP(
        '/', 72,
        '\\', 72,
        '`', 72,
        'b', 72,
        'f', 72,
        'n', 72,
        'r', 72,
        't', 72,
      );
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(96);
      END_STATE();
    case 96:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(96);
      END_STATE();
    default:
      return false;
  }
}

static const TSLexerMode ts_lex_modes[STATE_COUNT] = {
  [0] = {.lex_state = 0},
  [1] = {.lex_state = 0},
  [2] = {.lex_state = 3},
  [3] = {.lex_state = 3},
  [4] = {.lex_state = 3},
  [5] = {.lex_state = 3},
  [6] = {.lex_state = 3},
  [7] = {.lex_state = 2},
  [8] = {.lex_state = 2},
  [9] = {.lex_state = 2},
  [10] = {.lex_state = 2},
  [11] = {.lex_state = 2},
  [12] = {.lex_state = 2},
  [13] = {.lex_state = 2},
  [14] = {.lex_state = 2},
  [15] = {.lex_state = 2},
  [16] = {.lex_state = 2},
  [17] = {.lex_state = 2},
  [18] = {.lex_state = 21},
  [19] = {.lex_state = 2},
  [20] = {.lex_state = 21},
  [21] = {.lex_state = 0},
  [22] = {.lex_state = 0},
  [23] = {.lex_state = 0},
  [24] = {.lex_state = 0},
  [25] = {.lex_state = 2},
  [26] = {.lex_state = 2},
  [27] = {.lex_state = 21},
  [28] = {.lex_state = 2},
  [29] = {.lex_state = 21},
  [30] = {.lex_state = 2},
  [31] = {.lex_state = 0},
  [32] = {.lex_state = 0},
  [33] = {.lex_state = 0},
  [34] = {.lex_state = 0},
  [35] = {.lex_state = 0},
  [36] = {.lex_state = 0},
  [37] = {.lex_state = 0},
  [38] = {.lex_state = 0},
  [39] = {.lex_state = 0},
  [40] = {.lex_state = 0},
  [41] = {.lex_state = 0},
  [42] = {.lex_state = 0},
  [43] = {.lex_state = 0},
  [44] = {.lex_state = 0},
  [45] = {.lex_state = 0},
  [46] = {.lex_state = 0},
  [47] = {.lex_state = 0},
  [48] = {.lex_state = 0},
  [49] = {.lex_state = 0},
  [50] = {.lex_state = 0},
  [51] = {.lex_state = 0},
  [52] = {.lex_state = 0},
  [53] = {.lex_state = 0},
  [54] = {.lex_state = 3},
  [55] = {.lex_state = 3},
  [56] = {.lex_state = 0},
  [57] = {.lex_state = 0},
  [58] = {.lex_state = 0},
  [59] = {.lex_state = 0},
  [60] = {.lex_state = 0},
  [61] = {.lex_state = 0},
  [62] = {.lex_state = 0},
  [63] = {.lex_state = 0},
  [64] = {.lex_state = 0},
  [65] = {.lex_state = 0},
  [66] = {.lex_state = 0},
  [67] = {.lex_state = 0},
  [68] = {.lex_state = 0},
  [69] = {.lex_state = 0},
  [70] = {.lex_state = 0},
  [71] = {.lex_state = 0},
  [72] = {.lex_state = 0},
  [73] = {.lex_state = 0},
  [74] = {.lex_state = 0},
  [75] = {.lex_state = 0},
  [76] = {.lex_state = 0},
  [77] = {.lex_state = 0},
  [78] = {.lex_state = 0},
  [79] = {.lex_state = 0},
  [80] = {.lex_state = 21},
  [81] = {.lex_state = 1},
  [82] = {.lex_state = 0},
  [83] = {.lex_state = 0},
  [84] = {.lex_state = 0},
  [85] = {.lex_state = 0},
  [86] = {.lex_state = 0},
  [87] = {.lex_state = 0},
  [88] = {.lex_state = 0},
  [89] = {.lex_state = 0},
  [90] = {.lex_state = 0},
  [91] = {.lex_state = 0},
  [92] = {.lex_state = 21},
  [93] = {.lex_state = 0},
  [94] = {.lex_state = 0},
  [95] = {.lex_state = 0},
  [96] = {.lex_state = 0},
  [97] = {.lex_state = 0},
  [98] = {.lex_state = 0},
  [99] = {.lex_state = 0},
  [100] = {.lex_state = 0},
  [101] = {.lex_state = 0},
  [102] = {.lex_state = 0},
  [103] = {.lex_state = 0},
  [104] = {.lex_state = 0},
  [105] = {.lex_state = 0},
  [106] = {.lex_state = 0},
  [107] = {.lex_state = 1},
  [108] = {.lex_state = 0},
  [109] = {.lex_state = 21},
  [110] = {.lex_state = 0},
  [111] = {.lex_state = 0},
  [112] = {.lex_state = 0},
  [113] = {.lex_state = 9},
  [114] = {.lex_state = 0},
  [115] = {.lex_state = 0},
  [116] = {.lex_state = 0},
  [117] = {.lex_state = 0},
  [118] = {.lex_state = 9},
  [119] = {.lex_state = 0},
  [120] = {.lex_state = 21},
  [121] = {.lex_state = 0},
  [122] = {.lex_state = 0},
  [123] = {.lex_state = 0},
  [124] = {.lex_state = 0},
  [125] = {.lex_state = 0},
  [126] = {.lex_state = 21},
  [127] = {.lex_state = 0},
  [128] = {.lex_state = 0},
  [129] = {.lex_state = 21},
  [130] = {.lex_state = 0},
  [131] = {.lex_state = 0},
  [132] = {.lex_state = 0},
  [133] = {.lex_state = 0},
  [134] = {.lex_state = 0},
  [135] = {.lex_state = 0},
  [136] = {.lex_state = 0},
  [137] = {.lex_state = 0},
  [138] = {.lex_state = 0},
  [139] = {.lex_state = 0},
  [140] = {.lex_state = 0},
  [141] = {.lex_state = 0},
  [142] = {.lex_state = 2},
  [143] = {.lex_state = 0},
  [144] = {.lex_state = 0},
  [145] = {.lex_state = 0},
  [146] = {.lex_state = 0},
  [147] = {.lex_state = 0},
  [148] = {.lex_state = 0},
  [149] = {.lex_state = 0},
  [150] = {.lex_state = 0},
  [151] = {.lex_state = 0},
  [152] = {.lex_state = 0},
  [153] = {.lex_state = 0},
  [154] = {.lex_state = 0},
  [155] = {.lex_state = 0},
  [156] = {.lex_state = 0},
  [157] = {.lex_state = 0},
  [158] = {.lex_state = 0},
  [159] = {.lex_state = 0},
  [160] = {.lex_state = 0},
  [161] = {.lex_state = 0},
  [162] = {.lex_state = 0},
  [163] = {.lex_state = 0},
  [164] = {.lex_state = 0},
  [165] = {.lex_state = 60},
  [166] = {.lex_state = 65},
  [167] = {.lex_state = 0},
  [168] = {.lex_state = 69},
  [169] = {.lex_state = 0},
  [170] = {.lex_state = 0},
  [171] = {.lex_state = 69},
  [172] = {.lex_state = 0},
  [173] = {.lex_state = 1},
  [174] = {.lex_state = 0},
  [175] = {.lex_state = 2},
  [176] = {.lex_state = 0},
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
  [STATE(0)] = {
    [ts_builtin_sym_end] = ACTIONS(1),
    [anon_sym_LBRACK] = ACTIONS(1),
    [anon_sym_PIPE] = ACTIONS(1),
    [anon_sym_RBRACK] = ACTIONS(1),
    [anon_sym_COMMA] = ACTIONS(1),
    [anon_sym_AT] = ACTIONS(1),
    [anon_sym_LPAREN] = ACTIONS(1),
    [anon_sym_RPAREN] = ACTIONS(1),
    [anon_sym_AT_AT] = ACTIONS(1),
    [anon_sym_COLON] = ACTIONS(1),
    [anon_sym_COLON_COLON] = ACTIONS(1),
    [anon_sym_LBRACE] = ACTIONS(1),
    [anon_sym_RBRACE] = ACTIONS(1),
    [sym_symbol] = ACTIONS(1),
    [anon_sym_DOT_DOT] = ACTIONS(1),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1),
    [anon_sym_true] = ACTIONS(1),
    [anon_sym_false] = ACTIONS(1),
    [sym_integer] = ACTIONS(1),
    [sym_decimal] = ACTIONS(1),
    [sym_hexadecimal] = ACTIONS(1),
    [sym_octal] = ACTIONS(1),
    [sym_measurement] = ACTIONS(1),
    [anon_sym_SQUOTE] = ACTIONS(1),
    [anon_sym_DQUOTE] = ACTIONS(1),
    [anon_sym_BQUOTE] = ACTIONS(1),
    [anon_sym_BQUOTE_BQUOTE_BQUOTE] = ACTIONS(1),
    [anon_sym_DASH] = ACTIONS(1),
    [anon_sym_EQ] = ACTIONS(1),
    [anon_sym_TILDE] = ACTIONS(1),
    [anon_sym_DASH_GT] = ACTIONS(1),
    [anon_sym_EQ_GT] = ACTIONS(1),
    [anon_sym_TILDE_GT] = ACTIONS(1),
    [anon_sym_LT_DASH] = ACTIONS(1),
    [anon_sym_LT_EQ] = ACTIONS(1),
    [anon_sym_LT_TILDE] = ACTIONS(1),
    [sym_comment] = ACTIONS(3),
  },
  [STATE(1)] = {
    [sym_gram_pattern] = STATE(146),
    [sym__top_level_pattern] = STATE(24),
    [sym_annotated_pattern] = STATE(24),
    [sym_subject_pattern] = STATE(24),
    [sym_annotations] = STATE(56),
    [sym_property_annotation] = STATE(64),
    [sym_identified_annotation] = STATE(65),
    [sym_node_pattern] = STATE(20),
    [sym_relationship_pattern] = STATE(24),
    [sym_record] = STATE(23),
    [aux_sym_gram_pattern_repeat1] = STATE(24),
    [aux_sym_annotations_repeat1] = STATE(64),
    [ts_builtin_sym_end] = ACTIONS(5),
    [anon_sym_LBRACK] = ACTIONS(7),
    [anon_sym_AT] = ACTIONS(9),
    [anon_sym_LPAREN] = ACTIONS(11),
    [anon_sym_AT_AT] = ACTIONS(13),
    [anon_sym_LBRACE] = ACTIONS(15),
    [sym_comment] = ACTIONS(3),
  },
};

static const uint16_t ts_small_parse_table[] = {
  [0] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(21), 1,
      sym_symbol,
    ACTIONS(23), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(31), 1,
      anon_sym_SQUOTE,
    ACTIONS(33), 1,
      anon_sym_DQUOTE,
    ACTIONS(35), 1,
      anon_sym_BQUOTE,
    ACTIONS(37), 1,
      anon_sym_BQUOTE_BQUOTE_BQUOTE,
    STATE(33), 1,
      sym__double_quoted_string,
    STATE(35), 1,
      sym__fenced_string,
    STATE(36), 1,
      sym__single_quoted_string,
    STATE(37), 1,
      sym__backticked_string,
    STATE(58), 1,
      sym__numeric_literal,
    ACTIONS(25), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(29), 2,
      sym_decimal,
      sym_octal,
    ACTIONS(27), 3,
      sym_integer,
      sym_hexadecimal,
      sym_measurement,
    STATE(167), 7,
      sym__value,
      sym_array,
      sym_map,
      sym_range,
      sym_boolean_literal,
      sym_string_literal,
      sym_tagged_string,
  [65] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(17), 1,
      anon_sym_LBRACK,
    ACTIONS(19), 1,
      anon_sym_LBRACE,
    ACTIONS(21), 1,
      sym_symbol,
    ACTIONS(23), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(31), 1,
      anon_sym_SQUOTE,
    ACTIONS(33), 1,
      anon_sym_DQUOTE,
    ACTIONS(35), 1,
      anon_sym_BQUOTE,
    ACTIONS(37), 1,
      anon_sym_BQUOTE_BQUOTE_BQUOTE,
    STATE(33), 1,
      sym__double_quoted_string,
    STATE(35), 1,
      sym__fenced_string,
    STATE(36), 1,
      sym__single_quoted_string,
    STATE(37), 1,
      sym__backticked_string,
    STATE(58), 1,
      sym__numeric_literal,
    ACTIONS(25), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(29), 2,
      sym_decimal,
      sym_octal,
    ACTIONS(27), 3,
      sym_integer,
      sym_hexadecimal,
      sym_measurement,
    STATE(114), 7,
      sym__value,
      sym_array,
      sym_map,
      sym_range,
      sym_boolean_literal,
      sym_string_literal,
      sym_tagged_string,
  [130] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(31), 1,
      anon_sym_SQUOTE,
    ACTIONS(33), 1,
      anon_sym_DQUOTE,
    ACTIONS(35), 1,
      anon_sym_BQUOTE,
    ACTIONS(37), 1,
      anon_sym_BQUOTE_BQUOTE_BQUOTE,
    ACTIONS(39), 1,
      sym_symbol,
    STATE(33), 1,
      sym__double_quoted_string,
    STATE(35), 1,
      sym__fenced_string,
    STATE(36), 1,
      sym__single_quoted_string,
    STATE(37), 1,
      sym__backticked_string,
    STATE(62), 1,
      sym__numeric_literal,
    ACTIONS(25), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(43), 2,
      sym_decimal,
      sym_octal,
    ACTIONS(41), 3,
      sym_integer,
      sym_hexadecimal,
      sym_measurement,
    STATE(121), 5,
      sym__scalar_value,
      sym_range,
      sym_boolean_literal,
      sym_string_literal,
      sym_tagged_string,
  [187] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(31), 1,
      anon_sym_SQUOTE,
    ACTIONS(33), 1,
      anon_sym_DQUOTE,
    ACTIONS(35), 1,
      anon_sym_BQUOTE,
    ACTIONS(37), 1,
      anon_sym_BQUOTE_BQUOTE_BQUOTE,
    ACTIONS(39), 1,
      sym_symbol,
    STATE(33), 1,
      sym__double_quoted_string,
    STATE(35), 1,
      sym__fenced_string,
    STATE(36), 1,
      sym__single_quoted_string,
    STATE(37), 1,
      sym__backticked_string,
    STATE(62), 1,
      sym__numeric_literal,
    ACTIONS(25), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(43), 2,
      sym_decimal,
      sym_octal,
    ACTIONS(41), 3,
      sym_integer,
      sym_hexadecimal,
      sym_measurement,
    STATE(86), 5,
      sym__scalar_value,
      sym_range,
      sym_boolean_literal,
      sym_string_literal,
      sym_tagged_string,
  [244] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(23), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(31), 1,
      anon_sym_SQUOTE,
    ACTIONS(33), 1,
      anon_sym_DQUOTE,
    ACTIONS(35), 1,
      anon_sym_BQUOTE,
    ACTIONS(37), 1,
      anon_sym_BQUOTE_BQUOTE_BQUOTE,
    ACTIONS(39), 1,
      sym_symbol,
    STATE(33), 1,
      sym__double_quoted_string,
    STATE(35), 1,
      sym__fenced_string,
    STATE(36), 1,
      sym__single_quoted_string,
    STATE(37), 1,
      sym__backticked_string,
    STATE(62), 1,
      sym__numeric_literal,
    ACTIONS(25), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(43), 2,
      sym_decimal,
      sym_octal,
    ACTIONS(41), 3,
      sym_integer,
      sym_hexadecimal,
      sym_measurement,
    STATE(124), 5,
      sym__scalar_value,
      sym_range,
      sym_boolean_literal,
      sym_string_literal,
      sym_tagged_string,
  [301] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15), 1,
      anon_sym_LBRACE,
    ACTIONS(31), 1,
      anon_sym_SQUOTE,
    ACTIONS(33), 1,
      anon_sym_DQUOTE,
    ACTIONS(35), 1,
      anon_sym_BQUOTE,
    ACTIONS(45), 1,
      anon_sym_PIPE,
    ACTIONS(47), 1,
      anon_sym_RBRACK,
    ACTIONS(49), 1,
      anon_sym_COLON,
    ACTIONS(51), 1,
      anon_sym_COLON_COLON,
    ACTIONS(55), 1,
      anon_sym_BQUOTE_BQUOTE_BQUOTE,
    STATE(33), 1,
      sym__double_quoted_string,
    STATE(35), 1,
      sym__fenced_string,
    STATE(36), 1,
      sym__single_quoted_string,
    STATE(37), 1,
      sym__backticked_string,
    STATE(60), 1,
      sym_labels,
    STATE(88), 1,
      sym_record,
    STATE(119), 1,
      sym__subject,
    ACTIONS(53), 2,
      sym_symbol,
      sym_integer,
    STATE(31), 2,
      sym__label,
      aux_sym_labels_repeat1,
    STATE(43), 2,
      sym__identifier,
      sym_string_literal,
  [365] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7), 1,
      anon_sym_LBRACK,
    ACTIONS(11), 1,
      anon_sym_LPAREN,
    ACTIONS(31), 1,
      anon_sym_SQUOTE,
    ACTIONS(33), 1,
      anon_sym_DQUOTE,
    ACTIONS(35), 1,
      anon_sym_BQUOTE,
    ACTIONS(55), 1,
      anon_sym_BQUOTE_BQUOTE_BQUOTE,
    STATE(18), 1,
      sym_node_pattern,
    STATE(33), 1,
      sym__double_quoted_string,
    STATE(35), 1,
      sym__fenced_string,
    STATE(36), 1,
      sym__single_quoted_string,
    STATE(37), 1,
      sym__backticked_string,
    STATE(151), 1,
      sym_subject_pattern_elements,
    ACTIONS(57), 2,
      sym_symbol,
      sym_integer,
    STATE(117), 2,
      sym__identifier,
      sym_string_literal,
    STATE(78), 5,
      sym_subject_pattern,
      sym__subject_pattern_element,
      sym__path_pattern,
      sym_relationship_pattern,
      sym_pattern_reference,
  [420] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15), 1,
      anon_sym_LBRACE,
    ACTIONS(31), 1,
      anon_sym_SQUOTE,
    ACTIONS(33), 1,
      anon_sym_DQUOTE,
    ACTIONS(35), 1,
      anon_sym_BQUOTE,
    ACTIONS(49), 1,
      anon_sym_COLON,
    ACTIONS(51), 1,
      anon_sym_COLON_COLON,
    ACTIONS(55), 1,
      anon_sym_BQUOTE_BQUOTE_BQUOTE,
    ACTIONS(59), 1,
      anon_sym_RPAREN,
    STATE(33), 1,
      sym__double_quoted_string,
    STATE(35), 1,
      sym__fenced_string,
    STATE(36), 1,
      sym__single_quoted_string,
    STATE(37), 1,
      sym__backticked_string,
    STATE(60), 1,
      sym_labels,
    STATE(88), 1,
      sym_record,
    STATE(152), 1,
      sym__subject,
    ACTIONS(53), 2,
      sym_symbol,
      sym_integer,
    STATE(31), 2,
      sym__label,
      aux_sym_labels_repeat1,
    STATE(43), 2,
      sym__identifier,
      sym_string_literal,
  [481] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7), 1,
      anon_sym_LBRACK,
    ACTIONS(11), 1,
      anon_sym_LPAREN,
    ACTIONS(31), 1,
      anon_sym_SQUOTE,
    ACTIONS(33), 1,
      anon_sym_DQUOTE,
    ACTIONS(35), 1,
      anon_sym_BQUOTE,
    ACTIONS(55), 1,
      anon_sym_BQUOTE_BQUOTE_BQUOTE,
    STATE(18), 1,
      sym_node_pattern,
    STATE(33), 1,
      sym__double_quoted_string,
    STATE(35), 1,
      sym__fenced_string,
    STATE(36), 1,
      sym__single_quoted_string,
    STATE(37), 1,
      sym__backticked_string,
    STATE(144), 1,
      sym_subject_pattern_elements,
    ACTIONS(57), 2,
      sym_symbol,
      sym_integer,
    STATE(117), 2,
      sym__identifier,
      sym_string_literal,
    STATE(78), 5,
      sym_subject_pattern,
      sym__subject_pattern_element,
      sym__path_pattern,
      sym_relationship_pattern,
      sym_pattern_reference,
  [536] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15), 1,
      anon_sym_LBRACE,
    ACTIONS(31), 1,
      anon_sym_SQUOTE,
    ACTIONS(33), 1,
      anon_sym_DQUOTE,
    ACTIONS(35), 1,
      anon_sym_BQUOTE,
    ACTIONS(49), 1,
      anon_sym_COLON,
    ACTIONS(51), 1,
      anon_sym_COLON_COLON,
    ACTIONS(55), 1,
      anon_sym_BQUOTE_BQUOTE_BQUOTE,
    ACTIONS(61), 1,
      anon_sym_RBRACK,
    STATE(33), 1,
      sym__double_quoted_string,
    STATE(35), 1,
      sym__fenced_string,
    STATE(36), 1,
      sym__single_quoted_string,
    STATE(37), 1,
      sym__backticked_string,
    STATE(60), 1,
      sym_labels,
    STATE(88), 1,
      sym_record,
    STATE(141), 1,
      sym__subject,
    ACTIONS(53), 2,
      sym_symbol,
      sym_integer,
    STATE(31), 2,
      sym__label,
      aux_sym_labels_repeat1,
    STATE(43), 2,
      sym__identifier,
      sym_string_literal,
  [597] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15), 1,
      anon_sym_LBRACE,
    ACTIONS(31), 1,
      anon_sym_SQUOTE,
    ACTIONS(33), 1,
      anon_sym_DQUOTE,
    ACTIONS(35), 1,
      anon_sym_BQUOTE,
    ACTIONS(49), 1,
      anon_sym_COLON,
    ACTIONS(51), 1,
      anon_sym_COLON_COLON,
    ACTIONS(55), 1,
      anon_sym_BQUOTE_BQUOTE_BQUOTE,
    ACTIONS(63), 1,
      anon_sym_RBRACK,
    STATE(33), 1,
      sym__double_quoted_string,
    STATE(35), 1,
      sym__fenced_string,
    STATE(36), 1,
      sym__single_quoted_string,
    STATE(37), 1,
      sym__backticked_string,
    STATE(60), 1,
      sym_labels,
    STATE(88), 1,
      sym_record,
    STATE(145), 1,
      sym__subject,
    ACTIONS(53), 2,
      sym_symbol,
      sym_integer,
    STATE(31), 2,
      sym__label,
      aux_sym_labels_repeat1,
    STATE(43), 2,
      sym__identifier,
      sym_string_literal,
  [658] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15), 1,
      anon_sym_LBRACE,
    ACTIONS(31), 1,
      anon_sym_SQUOTE,
    ACTIONS(33), 1,
      anon_sym_DQUOTE,
    ACTIONS(35), 1,
      anon_sym_BQUOTE,
    ACTIONS(49), 1,
      anon_sym_COLON,
    ACTIONS(51), 1,
      anon_sym_COLON_COLON,
    ACTIONS(55), 1,
      anon_sym_BQUOTE_BQUOTE_BQUOTE,
    ACTIONS(65), 1,
      anon_sym_RBRACK,
    STATE(33), 1,
      sym__double_quoted_string,
    STATE(35), 1,
      sym__fenced_string,
    STATE(36), 1,
      sym__single_quoted_string,
    STATE(37), 1,
      sym__backticked_string,
    STATE(60), 1,
      sym_labels,
    STATE(88), 1,
      sym_record,
    STATE(148), 1,
      sym__subject,
    ACTIONS(53), 2,
      sym_symbol,
      sym_integer,
    STATE(31), 2,
      sym__label,
      aux_sym_labels_repeat1,
    STATE(43), 2,
      sym__identifier,
      sym_string_literal,
  [719] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15), 1,
      anon_sym_LBRACE,
    ACTIONS(31), 1,
      anon_sym_SQUOTE,
    ACTIONS(33), 1,
      anon_sym_DQUOTE,
    ACTIONS(35), 1,
      anon_sym_BQUOTE,
    ACTIONS(49), 1,
      anon_sym_COLON,
    ACTIONS(51), 1,
      anon_sym_COLON_COLON,
    ACTIONS(55), 1,
      anon_sym_BQUOTE_BQUOTE_BQUOTE,
    ACTIONS(67), 1,
      anon_sym_RBRACK,
    STATE(33), 1,
      sym__double_quoted_string,
    STATE(35), 1,
      sym__fenced_string,
    STATE(36), 1,
      sym__single_quoted_string,
    STATE(37), 1,
      sym__backticked_string,
    STATE(60), 1,
      sym_labels,
    STATE(88), 1,
      sym_record,
    STATE(137), 1,
      sym__subject,
    ACTIONS(53), 2,
      sym_symbol,
      sym_integer,
    STATE(31), 2,
      sym__label,
      aux_sym_labels_repeat1,
    STATE(43), 2,
      sym__identifier,
      sym_string_literal,
  [780] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15), 1,
      anon_sym_LBRACE,
    ACTIONS(31), 1,
      anon_sym_SQUOTE,
    ACTIONS(33), 1,
      anon_sym_DQUOTE,
    ACTIONS(35), 1,
      anon_sym_BQUOTE,
    ACTIONS(49), 1,
      anon_sym_COLON,
    ACTIONS(51), 1,
      anon_sym_COLON_COLON,
    ACTIONS(55), 1,
      anon_sym_BQUOTE_BQUOTE_BQUOTE,
    ACTIONS(69), 1,
      anon_sym_RBRACK,
    STATE(33), 1,
      sym__double_quoted_string,
    STATE(35), 1,
      sym__fenced_string,
    STATE(36), 1,
      sym__single_quoted_string,
    STATE(37), 1,
      sym__backticked_string,
    STATE(60), 1,
      sym_labels,
    STATE(88), 1,
      sym_record,
    STATE(135), 1,
      sym__subject,
    ACTIONS(53), 2,
      sym_symbol,
      sym_integer,
    STATE(31), 2,
      sym__label,
      aux_sym_labels_repeat1,
    STATE(43), 2,
      sym__identifier,
      sym_string_literal,
  [841] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15), 1,
      anon_sym_LBRACE,
    ACTIONS(31), 1,
      anon_sym_SQUOTE,
    ACTIONS(33), 1,
      anon_sym_DQUOTE,
    ACTIONS(35), 1,
      anon_sym_BQUOTE,
    ACTIONS(49), 1,
      anon_sym_COLON,
    ACTIONS(51), 1,
      anon_sym_COLON_COLON,
    ACTIONS(55), 1,
      anon_sym_BQUOTE_BQUOTE_BQUOTE,
    ACTIONS(71), 1,
      anon_sym_RBRACK,
    STATE(33), 1,
      sym__double_quoted_string,
    STATE(35), 1,
      sym__fenced_string,
    STATE(36), 1,
      sym__single_quoted_string,
    STATE(37), 1,
      sym__backticked_string,
    STATE(60), 1,
      sym_labels,
    STATE(88), 1,
      sym_record,
    STATE(143), 1,
      sym__subject,
    ACTIONS(53), 2,
      sym_symbol,
      sym_integer,
    STATE(31), 2,
      sym__label,
      aux_sym_labels_repeat1,
    STATE(43), 2,
      sym__identifier,
      sym_string_literal,
  [902] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7), 1,
      anon_sym_LBRACK,
    ACTIONS(11), 1,
      anon_sym_LPAREN,
    ACTIONS(31), 1,
      anon_sym_SQUOTE,
    ACTIONS(33), 1,
      anon_sym_DQUOTE,
    ACTIONS(35), 1,
      anon_sym_BQUOTE,
    ACTIONS(55), 1,
      anon_sym_BQUOTE_BQUOTE_BQUOTE,
    STATE(18), 1,
      sym_node_pattern,
    STATE(33), 1,
      sym__double_quoted_string,
    STATE(35), 1,
      sym__fenced_string,
    STATE(36), 1,
      sym__single_quoted_string,
    STATE(37), 1,
      sym__backticked_string,
    ACTIONS(57), 2,
      sym_symbol,
      sym_integer,
    STATE(117), 2,
      sym__identifier,
      sym_string_literal,
    STATE(112), 5,
      sym_subject_pattern,
      sym__subject_pattern_element,
      sym__path_pattern,
      sym_relationship_pattern,
      sym_pattern_reference,
  [954] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(75), 1,
      anon_sym_AT,
    ACTIONS(77), 1,
      anon_sym_DASH,
    ACTIONS(79), 1,
      anon_sym_EQ,
    ACTIONS(81), 1,
      anon_sym_TILDE,
    ACTIONS(83), 1,
      anon_sym_LT_DASH,
    ACTIONS(85), 1,
      anon_sym_LT_EQ,
    ACTIONS(87), 1,
      anon_sym_LT_TILDE,
    STATE(68), 5,
      sym__relationship_kind,
      sym_undirected_arrow,
      sym_right_arrow,
      sym_left_arrow,
      sym_bidirectional_arrow,
    ACTIONS(73), 6,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_AT_AT,
  [994] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(31), 1,
      anon_sym_SQUOTE,
    ACTIONS(33), 1,
      anon_sym_DQUOTE,
    ACTIONS(35), 1,
      anon_sym_BQUOTE,
    ACTIONS(49), 1,
      anon_sym_COLON,
    ACTIONS(51), 1,
      anon_sym_COLON_COLON,
    ACTIONS(55), 1,
      anon_sym_BQUOTE_BQUOTE_BQUOTE,
    STATE(33), 1,
      sym__double_quoted_string,
    STATE(35), 1,
      sym__fenced_string,
    STATE(36), 1,
      sym__single_quoted_string,
    STATE(37), 1,
      sym__backticked_string,
    STATE(91), 1,
      sym_labels,
    ACTIONS(89), 2,
      sym_symbol,
      sym_integer,
    STATE(31), 2,
      sym__label,
      aux_sym_labels_repeat1,
    STATE(48), 2,
      sym__identifier,
      sym_string_literal,
  [1043] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(77), 1,
      anon_sym_DASH,
    ACTIONS(79), 1,
      anon_sym_EQ,
    ACTIONS(81), 1,
      anon_sym_TILDE,
    ACTIONS(83), 1,
      anon_sym_LT_DASH,
    ACTIONS(85), 1,
      anon_sym_LT_EQ,
    ACTIONS(87), 1,
      anon_sym_LT_TILDE,
    ACTIONS(93), 1,
      anon_sym_AT,
    ACTIONS(91), 4,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_AT_AT,
    STATE(68), 5,
      sym__relationship_kind,
      sym_undirected_arrow,
      sym_right_arrow,
      sym_left_arrow,
      sym_bidirectional_arrow,
  [1081] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7), 1,
      anon_sym_LBRACK,
    ACTIONS(9), 1,
      anon_sym_AT,
    ACTIONS(11), 1,
      anon_sym_LPAREN,
    ACTIONS(13), 1,
      anon_sym_AT_AT,
    ACTIONS(95), 1,
      ts_builtin_sym_end,
    STATE(20), 1,
      sym_node_pattern,
    STATE(56), 1,
      sym_annotations,
    STATE(65), 1,
      sym_identified_annotation,
    STATE(64), 2,
      sym_property_annotation,
      aux_sym_annotations_repeat1,
    STATE(22), 5,
      sym__top_level_pattern,
      sym_annotated_pattern,
      sym_subject_pattern,
      sym_relationship_pattern,
      aux_sym_gram_pattern_repeat1,
  [1120] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(97), 1,
      ts_builtin_sym_end,
    ACTIONS(99), 1,
      anon_sym_LBRACK,
    ACTIONS(102), 1,
      anon_sym_AT,
    ACTIONS(105), 1,
      anon_sym_LPAREN,
    ACTIONS(108), 1,
      anon_sym_AT_AT,
    STATE(20), 1,
      sym_node_pattern,
    STATE(56), 1,
      sym_annotations,
    STATE(65), 1,
      sym_identified_annotation,
    STATE(64), 2,
      sym_property_annotation,
      aux_sym_annotations_repeat1,
    STATE(22), 5,
      sym__top_level_pattern,
      sym_annotated_pattern,
      sym_subject_pattern,
      sym_relationship_pattern,
      aux_sym_gram_pattern_repeat1,
  [1159] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7), 1,
      anon_sym_LBRACK,
    ACTIONS(9), 1,
      anon_sym_AT,
    ACTIONS(11), 1,
      anon_sym_LPAREN,
    ACTIONS(13), 1,
      anon_sym_AT_AT,
    ACTIONS(111), 1,
      ts_builtin_sym_end,
    STATE(20), 1,
      sym_node_pattern,
    STATE(56), 1,
      sym_annotations,
    STATE(65), 1,
      sym_identified_annotation,
    STATE(64), 2,
      sym_property_annotation,
      aux_sym_annotations_repeat1,
    STATE(21), 5,
      sym__top_level_pattern,
      sym_annotated_pattern,
      sym_subject_pattern,
      sym_relationship_pattern,
      aux_sym_gram_pattern_repeat1,
  [1198] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7), 1,
      anon_sym_LBRACK,
    ACTIONS(9), 1,
      anon_sym_AT,
    ACTIONS(11), 1,
      anon_sym_LPAREN,
    ACTIONS(13), 1,
      anon_sym_AT_AT,
    ACTIONS(113), 1,
      ts_builtin_sym_end,
    STATE(20), 1,
      sym_node_pattern,
    STATE(56), 1,
      sym_annotations,
    STATE(65), 1,
      sym_identified_annotation,
    STATE(64), 2,
      sym_property_annotation,
      aux_sym_annotations_repeat1,
    STATE(22), 5,
      sym__top_level_pattern,
      sym_annotated_pattern,
      sym_subject_pattern,
      sym_relationship_pattern,
      aux_sym_gram_pattern_repeat1,
  [1237] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(31), 1,
      anon_sym_SQUOTE,
    ACTIONS(33), 1,
      anon_sym_DQUOTE,
    ACTIONS(35), 1,
      anon_sym_BQUOTE,
    ACTIONS(55), 1,
      anon_sym_BQUOTE_BQUOTE_BQUOTE,
    ACTIONS(115), 1,
      anon_sym_RBRACE,
    STATE(33), 1,
      sym__double_quoted_string,
    STATE(35), 1,
      sym__fenced_string,
    STATE(36), 1,
      sym__single_quoted_string,
    STATE(37), 1,
      sym__backticked_string,
    STATE(99), 1,
      sym_record_property,
    ACTIONS(117), 2,
      sym_symbol,
      sym_integer,
    STATE(115), 2,
      sym__identifier,
      sym_string_literal,
  [1279] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(31), 1,
      anon_sym_SQUOTE,
    ACTIONS(33), 1,
      anon_sym_DQUOTE,
    ACTIONS(35), 1,
      anon_sym_BQUOTE,
    ACTIONS(55), 1,
      anon_sym_BQUOTE_BQUOTE_BQUOTE,
    ACTIONS(119), 1,
      anon_sym_RBRACE,
    STATE(33), 1,
      sym__double_quoted_string,
    STATE(35), 1,
      sym__fenced_string,
    STATE(36), 1,
      sym__single_quoted_string,
    STATE(37), 1,
      sym__backticked_string,
    STATE(106), 1,
      sym_map_entry,
    ACTIONS(121), 2,
      sym_symbol,
      sym_integer,
    STATE(169), 2,
      sym__identifier,
      sym_string_literal,
  [1321] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      anon_sym_AT,
    ACTIONS(123), 12,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_AT_AT,
      anon_sym_DASH,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_EQ,
      anon_sym_LT_TILDE,
  [1342] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(31), 1,
      anon_sym_SQUOTE,
    ACTIONS(33), 1,
      anon_sym_DQUOTE,
    ACTIONS(35), 1,
      anon_sym_BQUOTE,
    ACTIONS(55), 1,
      anon_sym_BQUOTE_BQUOTE_BQUOTE,
    STATE(33), 1,
      sym__double_quoted_string,
    STATE(35), 1,
      sym__fenced_string,
    STATE(36), 1,
      sym__single_quoted_string,
    STATE(37), 1,
      sym__backticked_string,
    STATE(116), 1,
      sym_record_property,
    ACTIONS(117), 2,
      sym_symbol,
      sym_integer,
    STATE(115), 2,
      sym__identifier,
      sym_string_literal,
  [1381] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(129), 1,
      anon_sym_AT,
    ACTIONS(127), 12,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_AT_AT,
      anon_sym_DASH,
      anon_sym_EQ,
      anon_sym_TILDE,
      anon_sym_LT_DASH,
      anon_sym_LT_EQ,
      anon_sym_LT_TILDE,
  [1402] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(31), 1,
      anon_sym_SQUOTE,
    ACTIONS(33), 1,
      anon_sym_DQUOTE,
    ACTIONS(35), 1,
      anon_sym_BQUOTE,
    ACTIONS(55), 1,
      anon_sym_BQUOTE_BQUOTE_BQUOTE,
    STATE(33), 1,
      sym__double_quoted_string,
    STATE(35), 1,
      sym__fenced_string,
    STATE(36), 1,
      sym__single_quoted_string,
    STATE(37), 1,
      sym__backticked_string,
    STATE(125), 1,
      sym_map_entry,
    ACTIONS(121), 2,
      sym_symbol,
      sym_integer,
    STATE(169), 2,
      sym__identifier,
      sym_string_literal,
  [1441] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym_COLON,
    ACTIONS(51), 1,
      anon_sym_COLON_COLON,
    STATE(34), 2,
      sym__label,
      aux_sym_labels_repeat1,
    ACTIONS(131), 7,
      anon_sym_LBRACK,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
  [1464] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(135), 1,
      anon_sym_COLON,
    ACTIONS(133), 10,
      anon_sym_LBRACK,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [1483] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(139), 1,
      anon_sym_COLON,
    ACTIONS(137), 10,
      anon_sym_LBRACK,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [1502] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(143), 1,
      anon_sym_COLON,
    ACTIONS(146), 1,
      anon_sym_COLON_COLON,
    STATE(34), 2,
      sym__label,
      aux_sym_labels_repeat1,
    ACTIONS(141), 7,
      anon_sym_LBRACK,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
  [1525] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(139), 1,
      anon_sym_COLON,
    ACTIONS(137), 10,
      anon_sym_LBRACK,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [1544] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(139), 1,
      anon_sym_COLON,
    ACTIONS(137), 10,
      anon_sym_LBRACK,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [1563] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(139), 1,
      anon_sym_COLON,
    ACTIONS(137), 10,
      anon_sym_LBRACK,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [1582] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(151), 1,
      anon_sym_COLON,
    ACTIONS(149), 10,
      anon_sym_LBRACK,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [1601] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(155), 1,
      anon_sym_COLON,
    ACTIONS(153), 10,
      anon_sym_LBRACK,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [1620] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(159), 1,
      anon_sym_COLON,
    ACTIONS(157), 10,
      anon_sym_LBRACK,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [1639] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(163), 1,
      anon_sym_COLON,
    ACTIONS(161), 10,
      anon_sym_LBRACK,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [1658] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(167), 1,
      anon_sym_COLON,
    ACTIONS(165), 10,
      anon_sym_LBRACK,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [1677] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15), 1,
      anon_sym_LBRACE,
    ACTIONS(49), 1,
      anon_sym_COLON,
    ACTIONS(51), 1,
      anon_sym_COLON_COLON,
    STATE(59), 1,
      sym_labels,
    STATE(84), 1,
      sym_record,
    STATE(31), 2,
      sym__label,
      aux_sym_labels_repeat1,
    ACTIONS(169), 3,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
  [1705] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(173), 1,
      anon_sym_COLON,
    ACTIONS(171), 8,
      anon_sym_LBRACK,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
  [1722] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(177), 1,
      anon_sym_AT,
    ACTIONS(175), 7,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_AT_AT,
  [1738] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(181), 1,
      anon_sym_AT,
    ACTIONS(179), 7,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_AT_AT,
  [1754] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(185), 1,
      anon_sym_AT,
    ACTIONS(183), 7,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_AT_AT,
  [1770] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym_COLON,
    ACTIONS(51), 1,
      anon_sym_COLON_COLON,
    STATE(85), 1,
      sym_labels,
    STATE(31), 2,
      sym__label,
      aux_sym_labels_repeat1,
    ACTIONS(187), 3,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_LPAREN,
  [1792] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(191), 1,
      anon_sym_AT,
    ACTIONS(189), 6,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_AT_AT,
  [1807] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(195), 1,
      anon_sym_AT,
    ACTIONS(193), 6,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_AT_AT,
  [1822] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(199), 1,
      anon_sym_AT,
    ACTIONS(197), 6,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_AT_AT,
  [1837] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(203), 1,
      anon_sym_AT,
    ACTIONS(201), 6,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_AT_AT,
  [1852] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(207), 1,
      anon_sym_AT,
    ACTIONS(205), 6,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_AT_AT,
  [1867] = 4,
    ACTIONS(3), 1,
      sym_comment,
    STATE(71), 1,
      sym__numeric_literal,
    ACTIONS(211), 2,
      sym_decimal,
      sym_octal,
    ACTIONS(209), 3,
      sym_integer,
      sym_hexadecimal,
      sym_measurement,
  [1883] = 4,
    ACTIONS(3), 1,
      sym_comment,
    STATE(73), 1,
      sym__numeric_literal,
    ACTIONS(215), 2,
      sym_decimal,
      sym_octal,
    ACTIONS(213), 3,
      sym_integer,
      sym_hexadecimal,
      sym_measurement,
  [1899] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7), 1,
      anon_sym_LBRACK,
    ACTIONS(11), 1,
      anon_sym_LPAREN,
    STATE(18), 1,
      sym_node_pattern,
    STATE(61), 3,
      sym_subject_pattern,
      sym__path_pattern,
      sym_relationship_pattern,
  [1917] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(219), 1,
      anon_sym_AT,
    ACTIONS(217), 2,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
    STATE(63), 2,
      sym_property_annotation,
      aux_sym_annotations_repeat1,
  [1932] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(223), 1,
      anon_sym_DOT_DOT,
    ACTIONS(225), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(221), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [1947] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15), 1,
      anon_sym_LBRACE,
    STATE(79), 1,
      sym_record,
    ACTIONS(227), 3,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
  [1962] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(15), 1,
      anon_sym_LBRACE,
    STATE(94), 1,
      sym_record,
    ACTIONS(229), 3,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
  [1977] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(233), 1,
      anon_sym_AT,
    ACTIONS(231), 4,
      ts_builtin_sym_end,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_AT_AT,
  [1990] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(223), 1,
      anon_sym_DOT_DOT,
    ACTIONS(225), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(235), 3,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [2005] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(239), 1,
      anon_sym_AT,
    ACTIONS(237), 2,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
    STATE(63), 2,
      sym_property_annotation,
      aux_sym_annotations_repeat1,
  [2020] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(219), 1,
      anon_sym_AT,
    ACTIONS(242), 2,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
    STATE(63), 2,
      sym_property_annotation,
      aux_sym_annotations_repeat1,
  [2035] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(219), 1,
      anon_sym_AT,
    ACTIONS(242), 2,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
    STATE(57), 2,
      sym_property_annotation,
      aux_sym_annotations_repeat1,
  [2050] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(244), 1,
      anon_sym_BQUOTE,
    ACTIONS(221), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [2062] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(246), 4,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [2072] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      anon_sym_LPAREN,
    STATE(18), 1,
      sym_node_pattern,
    STATE(51), 2,
      sym__path_pattern,
      sym_relationship_pattern,
  [2086] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(248), 4,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [2096] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(244), 1,
      anon_sym_BQUOTE,
    ACTIONS(235), 3,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [2108] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(250), 4,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [2118] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(252), 4,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [2128] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(254), 4,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [2138] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(256), 4,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [2148] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(258), 4,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [2158] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(260), 1,
      anon_sym_LBRACK,
    ACTIONS(262), 1,
      anon_sym_EQ,
    ACTIONS(264), 1,
      anon_sym_EQ_GT,
  [2171] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(266), 1,
      anon_sym_RBRACK,
    ACTIONS(268), 1,
      anon_sym_COMMA,
    STATE(83), 1,
      aux_sym_subject_pattern_elements_repeat1,
  [2184] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(268), 1,
      anon_sym_COMMA,
    ACTIONS(270), 1,
      anon_sym_RBRACK,
    STATE(77), 1,
      aux_sym_subject_pattern_elements_repeat1,
  [2197] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(272), 3,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
  [2206] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(262), 1,
      anon_sym_DASH,
    ACTIONS(264), 1,
      anon_sym_DASH_GT,
    ACTIONS(274), 1,
      anon_sym_LBRACK,
  [2219] = 4,
    ACTIONS(276), 1,
      sym_symbol,
    ACTIONS(278), 1,
      anon_sym_LF,
    ACTIONS(280), 1,
      sym_comment,
    STATE(32), 1,
      sym__fenced_string_body,
  [2232] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(282), 1,
      anon_sym_COMMA,
    ACTIONS(285), 1,
      anon_sym_RBRACE,
    STATE(82), 1,
      aux_sym_record_repeat1,
  [2245] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(287), 1,
      anon_sym_RBRACK,
    ACTIONS(289), 1,
      anon_sym_COMMA,
    STATE(83), 1,
      aux_sym_subject_pattern_elements_repeat1,
  [2258] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(292), 3,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
  [2267] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(294), 3,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_LPAREN,
  [2276] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(296), 1,
      anon_sym_RBRACK,
    ACTIONS(298), 1,
      anon_sym_COMMA,
    STATE(95), 1,
      aux_sym_array_repeat1,
  [2289] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(300), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [2298] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(302), 3,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
  [2307] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(262), 1,
      anon_sym_TILDE,
    ACTIONS(264), 1,
      anon_sym_TILDE_GT,
    ACTIONS(304), 1,
      anon_sym_LBRACK,
  [2320] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(306), 3,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_LPAREN,
  [2329] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(308), 3,
      anon_sym_LBRACK,
      anon_sym_AT,
      anon_sym_LPAREN,
  [2338] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(310), 1,
      anon_sym_LBRACK,
    ACTIONS(312), 1,
      anon_sym_DASH,
    ACTIONS(314), 1,
      anon_sym_DASH_GT,
  [2351] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(316), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [2360] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(318), 3,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
  [2369] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(298), 1,
      anon_sym_COMMA,
    ACTIONS(320), 1,
      anon_sym_RBRACK,
    STATE(101), 1,
      aux_sym_array_repeat1,
  [2382] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(322), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [2391] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(324), 1,
      anon_sym_COMMA,
    ACTIONS(326), 1,
      anon_sym_RBRACE,
    STATE(103), 1,
      aux_sym_map_repeat1,
  [2404] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(312), 1,
      anon_sym_EQ,
    ACTIONS(314), 1,
      anon_sym_EQ_GT,
    ACTIONS(328), 1,
      anon_sym_LBRACK,
  [2417] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(330), 1,
      anon_sym_COMMA,
    ACTIONS(332), 1,
      anon_sym_RBRACE,
    STATE(105), 1,
      aux_sym_record_repeat1,
  [2430] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(334), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [2439] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(336), 1,
      anon_sym_RBRACK,
    ACTIONS(338), 1,
      anon_sym_COMMA,
    STATE(101), 1,
      aux_sym_array_repeat1,
  [2452] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(341), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [2461] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(343), 1,
      anon_sym_COMMA,
    ACTIONS(346), 1,
      anon_sym_RBRACE,
    STATE(103), 1,
      aux_sym_map_repeat1,
  [2474] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(312), 1,
      anon_sym_TILDE,
    ACTIONS(314), 1,
      anon_sym_TILDE_GT,
    ACTIONS(348), 1,
      anon_sym_LBRACK,
  [2487] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(330), 1,
      anon_sym_COMMA,
    ACTIONS(350), 1,
      anon_sym_RBRACE,
    STATE(82), 1,
      aux_sym_record_repeat1,
  [2500] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(324), 1,
      anon_sym_COMMA,
    ACTIONS(352), 1,
      anon_sym_RBRACE,
    STATE(97), 1,
      aux_sym_map_repeat1,
  [2513] = 3,
    ACTIONS(278), 1,
      anon_sym_LF,
    ACTIONS(280), 1,
      sym_comment,
    STATE(32), 1,
      sym__fenced_string_body,
  [2523] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(354), 1,
      anon_sym_TILDE,
    ACTIONS(356), 1,
      anon_sym_TILDE_GT,
  [2533] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(358), 1,
      anon_sym_DASH,
    ACTIONS(360), 1,
      anon_sym_DASH_GT,
  [2543] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(362), 1,
      anon_sym_EQ,
    ACTIONS(364), 1,
      anon_sym_EQ_GT,
  [2553] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(366), 1,
      anon_sym_TILDE,
    ACTIONS(368), 1,
      anon_sym_TILDE_GT,
  [2563] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(287), 2,
      anon_sym_RBRACK,
      anon_sym_COMMA,
  [2571] = 3,
    ACTIONS(280), 1,
      sym_comment,
    ACTIONS(370), 1,
      anon_sym_BQUOTE_BQUOTE_BQUOTE,
    ACTIONS(372), 1,
      sym__fenced_string_content,
  [2581] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(374), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [2589] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(376), 1,
      anon_sym_COLON,
    ACTIONS(378), 1,
      anon_sym_COLON_COLON,
  [2599] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(285), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [2607] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(380), 2,
      anon_sym_RBRACK,
      anon_sym_COMMA,
  [2615] = 3,
    ACTIONS(280), 1,
      sym_comment,
    ACTIONS(382), 1,
      anon_sym_BQUOTE_BQUOTE_BQUOTE,
    ACTIONS(384), 1,
      sym__fenced_string_content,
  [2625] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(386), 1,
      anon_sym_PIPE,
    ACTIONS(388), 1,
      anon_sym_RBRACK,
  [2635] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(390), 1,
      anon_sym_DASH,
    ACTIONS(392), 1,
      anon_sym_DASH_GT,
  [2645] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(336), 2,
      anon_sym_RBRACK,
      anon_sym_COMMA,
  [2653] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(390), 1,
      anon_sym_EQ,
    ACTIONS(392), 1,
      anon_sym_EQ_GT,
  [2663] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(390), 1,
      anon_sym_TILDE,
    ACTIONS(392), 1,
      anon_sym_TILDE_GT,
  [2673] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(394), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [2681] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(346), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [2689] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(396), 1,
      anon_sym_DASH,
    ACTIONS(398), 1,
      anon_sym_DASH_GT,
  [2699] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(396), 1,
      anon_sym_EQ,
    ACTIONS(398), 1,
      anon_sym_EQ_GT,
  [2709] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(396), 1,
      anon_sym_TILDE,
    ACTIONS(398), 1,
      anon_sym_TILDE_GT,
  [2719] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(400), 1,
      anon_sym_DASH,
    ACTIONS(402), 1,
      anon_sym_DASH_GT,
  [2729] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(404), 1,
      anon_sym_EQ,
    ACTIONS(406), 1,
      anon_sym_EQ_GT,
  [2739] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
  [2746] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(410), 1,
      anon_sym_LPAREN,
  [2753] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(412), 1,
      anon_sym_LPAREN,
  [2760] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(414), 1,
      anon_sym_LPAREN,
  [2767] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(416), 1,
      anon_sym_RBRACK,
  [2774] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(418), 1,
      anon_sym_LPAREN,
  [2781] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(420), 1,
      anon_sym_RBRACK,
  [2788] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(422), 1,
      anon_sym_LPAREN,
  [2795] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(424), 1,
      anon_sym_LPAREN,
  [2802] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(426), 1,
      anon_sym_BQUOTE_BQUOTE_BQUOTE,
  [2809] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(428), 1,
      anon_sym_RBRACK,
  [2816] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(430), 1,
      sym_symbol,
  [2823] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(432), 1,
      anon_sym_RBRACK,
  [2830] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(434), 1,
      anon_sym_RBRACK,
  [2837] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(436), 1,
      anon_sym_RBRACK,
  [2844] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(438), 1,
      ts_builtin_sym_end,
  [2851] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(440), 1,
      anon_sym_LPAREN,
  [2858] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(442), 1,
      anon_sym_RBRACK,
  [2865] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(444), 1,
      anon_sym_SQUOTE,
  [2872] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(446), 1,
      anon_sym_BQUOTE,
  [2879] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(448), 1,
      anon_sym_RBRACK,
  [2886] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(450), 1,
      anon_sym_RPAREN,
  [2893] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(452), 1,
      anon_sym_LPAREN,
  [2900] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(454), 1,
      anon_sym_LPAREN,
  [2907] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(452), 1,
      anon_sym_LPAREN,
  [2914] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(454), 1,
      anon_sym_LPAREN,
  [2921] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(452), 1,
      anon_sym_LPAREN,
  [2928] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(454), 1,
      anon_sym_LPAREN,
  [2935] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
  [2942] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(456), 1,
      anon_sym_LPAREN,
  [2949] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(458), 1,
      anon_sym_BQUOTE,
  [2956] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(456), 1,
      anon_sym_LPAREN,
  [2963] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(408), 1,
      anon_sym_LPAREN,
  [2970] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(456), 1,
      anon_sym_LPAREN,
  [2977] = 2,
    ACTIONS(280), 1,
      sym_comment,
    ACTIONS(460), 1,
      sym__single_quoted_text,
  [2984] = 2,
    ACTIONS(280), 1,
      sym_comment,
    ACTIONS(462), 1,
      sym__double_quoted_text,
  [2991] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(464), 1,
      anon_sym_RPAREN,
  [2998] = 2,
    ACTIONS(280), 1,
      sym_comment,
    ACTIONS(466), 1,
      sym__backticked_text,
  [3005] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(468), 1,
      anon_sym_COLON,
  [3012] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(470), 1,
      anon_sym_LPAREN,
  [3019] = 2,
    ACTIONS(280), 1,
      sym_comment,
    ACTIONS(472), 1,
      sym__backticked_text,
  [3026] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(474), 1,
      anon_sym_LPAREN,
  [3033] = 2,
    ACTIONS(280), 1,
      sym_comment,
    ACTIONS(476), 1,
      anon_sym_LF,
  [3040] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(478), 1,
      anon_sym_BQUOTE_BQUOTE_BQUOTE,
  [3047] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(480), 1,
      sym_symbol,
  [3054] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(482), 1,
      anon_sym_DQUOTE,
};

static const uint32_t ts_small_parse_table_map[] = {
  [SMALL_STATE(2)] = 0,
  [SMALL_STATE(3)] = 65,
  [SMALL_STATE(4)] = 130,
  [SMALL_STATE(5)] = 187,
  [SMALL_STATE(6)] = 244,
  [SMALL_STATE(7)] = 301,
  [SMALL_STATE(8)] = 365,
  [SMALL_STATE(9)] = 420,
  [SMALL_STATE(10)] = 481,
  [SMALL_STATE(11)] = 536,
  [SMALL_STATE(12)] = 597,
  [SMALL_STATE(13)] = 658,
  [SMALL_STATE(14)] = 719,
  [SMALL_STATE(15)] = 780,
  [SMALL_STATE(16)] = 841,
  [SMALL_STATE(17)] = 902,
  [SMALL_STATE(18)] = 954,
  [SMALL_STATE(19)] = 994,
  [SMALL_STATE(20)] = 1043,
  [SMALL_STATE(21)] = 1081,
  [SMALL_STATE(22)] = 1120,
  [SMALL_STATE(23)] = 1159,
  [SMALL_STATE(24)] = 1198,
  [SMALL_STATE(25)] = 1237,
  [SMALL_STATE(26)] = 1279,
  [SMALL_STATE(27)] = 1321,
  [SMALL_STATE(28)] = 1342,
  [SMALL_STATE(29)] = 1381,
  [SMALL_STATE(30)] = 1402,
  [SMALL_STATE(31)] = 1441,
  [SMALL_STATE(32)] = 1464,
  [SMALL_STATE(33)] = 1483,
  [SMALL_STATE(34)] = 1502,
  [SMALL_STATE(35)] = 1525,
  [SMALL_STATE(36)] = 1544,
  [SMALL_STATE(37)] = 1563,
  [SMALL_STATE(38)] = 1582,
  [SMALL_STATE(39)] = 1601,
  [SMALL_STATE(40)] = 1620,
  [SMALL_STATE(41)] = 1639,
  [SMALL_STATE(42)] = 1658,
  [SMALL_STATE(43)] = 1677,
  [SMALL_STATE(44)] = 1705,
  [SMALL_STATE(45)] = 1722,
  [SMALL_STATE(46)] = 1738,
  [SMALL_STATE(47)] = 1754,
  [SMALL_STATE(48)] = 1770,
  [SMALL_STATE(49)] = 1792,
  [SMALL_STATE(50)] = 1807,
  [SMALL_STATE(51)] = 1822,
  [SMALL_STATE(52)] = 1837,
  [SMALL_STATE(53)] = 1852,
  [SMALL_STATE(54)] = 1867,
  [SMALL_STATE(55)] = 1883,
  [SMALL_STATE(56)] = 1899,
  [SMALL_STATE(57)] = 1917,
  [SMALL_STATE(58)] = 1932,
  [SMALL_STATE(59)] = 1947,
  [SMALL_STATE(60)] = 1962,
  [SMALL_STATE(61)] = 1977,
  [SMALL_STATE(62)] = 1990,
  [SMALL_STATE(63)] = 2005,
  [SMALL_STATE(64)] = 2020,
  [SMALL_STATE(65)] = 2035,
  [SMALL_STATE(66)] = 2050,
  [SMALL_STATE(67)] = 2062,
  [SMALL_STATE(68)] = 2072,
  [SMALL_STATE(69)] = 2086,
  [SMALL_STATE(70)] = 2096,
  [SMALL_STATE(71)] = 2108,
  [SMALL_STATE(72)] = 2118,
  [SMALL_STATE(73)] = 2128,
  [SMALL_STATE(74)] = 2138,
  [SMALL_STATE(75)] = 2148,
  [SMALL_STATE(76)] = 2158,
  [SMALL_STATE(77)] = 2171,
  [SMALL_STATE(78)] = 2184,
  [SMALL_STATE(79)] = 2197,
  [SMALL_STATE(80)] = 2206,
  [SMALL_STATE(81)] = 2219,
  [SMALL_STATE(82)] = 2232,
  [SMALL_STATE(83)] = 2245,
  [SMALL_STATE(84)] = 2258,
  [SMALL_STATE(85)] = 2267,
  [SMALL_STATE(86)] = 2276,
  [SMALL_STATE(87)] = 2289,
  [SMALL_STATE(88)] = 2298,
  [SMALL_STATE(89)] = 2307,
  [SMALL_STATE(90)] = 2320,
  [SMALL_STATE(91)] = 2329,
  [SMALL_STATE(92)] = 2338,
  [SMALL_STATE(93)] = 2351,
  [SMALL_STATE(94)] = 2360,
  [SMALL_STATE(95)] = 2369,
  [SMALL_STATE(96)] = 2382,
  [SMALL_STATE(97)] = 2391,
  [SMALL_STATE(98)] = 2404,
  [SMALL_STATE(99)] = 2417,
  [SMALL_STATE(100)] = 2430,
  [SMALL_STATE(101)] = 2439,
  [SMALL_STATE(102)] = 2452,
  [SMALL_STATE(103)] = 2461,
  [SMALL_STATE(104)] = 2474,
  [SMALL_STATE(105)] = 2487,
  [SMALL_STATE(106)] = 2500,
  [SMALL_STATE(107)] = 2513,
  [SMALL_STATE(108)] = 2523,
  [SMALL_STATE(109)] = 2533,
  [SMALL_STATE(110)] = 2543,
  [SMALL_STATE(111)] = 2553,
  [SMALL_STATE(112)] = 2563,
  [SMALL_STATE(113)] = 2571,
  [SMALL_STATE(114)] = 2581,
  [SMALL_STATE(115)] = 2589,
  [SMALL_STATE(116)] = 2599,
  [SMALL_STATE(117)] = 2607,
  [SMALL_STATE(118)] = 2615,
  [SMALL_STATE(119)] = 2625,
  [SMALL_STATE(120)] = 2635,
  [SMALL_STATE(121)] = 2645,
  [SMALL_STATE(122)] = 2653,
  [SMALL_STATE(123)] = 2663,
  [SMALL_STATE(124)] = 2673,
  [SMALL_STATE(125)] = 2681,
  [SMALL_STATE(126)] = 2689,
  [SMALL_STATE(127)] = 2699,
  [SMALL_STATE(128)] = 2709,
  [SMALL_STATE(129)] = 2719,
  [SMALL_STATE(130)] = 2729,
  [SMALL_STATE(131)] = 2739,
  [SMALL_STATE(132)] = 2746,
  [SMALL_STATE(133)] = 2753,
  [SMALL_STATE(134)] = 2760,
  [SMALL_STATE(135)] = 2767,
  [SMALL_STATE(136)] = 2774,
  [SMALL_STATE(137)] = 2781,
  [SMALL_STATE(138)] = 2788,
  [SMALL_STATE(139)] = 2795,
  [SMALL_STATE(140)] = 2802,
  [SMALL_STATE(141)] = 2809,
  [SMALL_STATE(142)] = 2816,
  [SMALL_STATE(143)] = 2823,
  [SMALL_STATE(144)] = 2830,
  [SMALL_STATE(145)] = 2837,
  [SMALL_STATE(146)] = 2844,
  [SMALL_STATE(147)] = 2851,
  [SMALL_STATE(148)] = 2858,
  [SMALL_STATE(149)] = 2865,
  [SMALL_STATE(150)] = 2872,
  [SMALL_STATE(151)] = 2879,
  [SMALL_STATE(152)] = 2886,
  [SMALL_STATE(153)] = 2893,
  [SMALL_STATE(154)] = 2900,
  [SMALL_STATE(155)] = 2907,
  [SMALL_STATE(156)] = 2914,
  [SMALL_STATE(157)] = 2921,
  [SMALL_STATE(158)] = 2928,
  [SMALL_STATE(159)] = 2935,
  [SMALL_STATE(160)] = 2942,
  [SMALL_STATE(161)] = 2949,
  [SMALL_STATE(162)] = 2956,
  [SMALL_STATE(163)] = 2963,
  [SMALL_STATE(164)] = 2970,
  [SMALL_STATE(165)] = 2977,
  [SMALL_STATE(166)] = 2984,
  [SMALL_STATE(167)] = 2991,
  [SMALL_STATE(168)] = 2998,
  [SMALL_STATE(169)] = 3005,
  [SMALL_STATE(170)] = 3012,
  [SMALL_STATE(171)] = 3019,
  [SMALL_STATE(172)] = 3026,
  [SMALL_STATE(173)] = 3033,
  [SMALL_STATE(174)] = 3040,
  [SMALL_STATE(175)] = 3047,
  [SMALL_STATE(176)] = 3054,
};

static const TSParseActionEntry ts_parse_actions[] = {
  [0] = {.entry = {.count = 0, .reusable = false}},
  [1] = {.entry = {.count = 1, .reusable = false}}, RECOVER(),
  [3] = {.entry = {.count = 1, .reusable = true}}, SHIFT_EXTRA(),
  [5] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gram_pattern, 0, 0, 0),
  [7] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7),
  [9] = {.entry = {.count = 1, .reusable = false}}, SHIFT(175),
  [11] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9),
  [13] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19),
  [15] = {.entry = {.count = 1, .reusable = true}}, SHIFT(25),
  [17] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5),
  [19] = {.entry = {.count = 1, .reusable = true}}, SHIFT(26),
  [21] = {.entry = {.count = 1, .reusable = false}}, SHIFT(66),
  [23] = {.entry = {.count = 1, .reusable = true}}, SHIFT(54),
  [25] = {.entry = {.count = 1, .reusable = false}}, SHIFT(69),
  [27] = {.entry = {.count = 1, .reusable = false}}, SHIFT(58),
  [29] = {.entry = {.count = 1, .reusable = true}}, SHIFT(58),
  [31] = {.entry = {.count = 1, .reusable = true}}, SHIFT(165),
  [33] = {.entry = {.count = 1, .reusable = true}}, SHIFT(166),
  [35] = {.entry = {.count = 1, .reusable = false}}, SHIFT(168),
  [37] = {.entry = {.count = 1, .reusable = true}}, SHIFT(81),
  [39] = {.entry = {.count = 1, .reusable = false}}, SHIFT(70),
  [41] = {.entry = {.count = 1, .reusable = false}}, SHIFT(62),
  [43] = {.entry = {.count = 1, .reusable = true}}, SHIFT(62),
  [45] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8),
  [47] = {.entry = {.count = 1, .reusable = true}}, SHIFT(50),
  [49] = {.entry = {.count = 1, .reusable = false}}, SHIFT(142),
  [51] = {.entry = {.count = 1, .reusable = true}}, SHIFT(142),
  [53] = {.entry = {.count = 1, .reusable = true}}, SHIFT(43),
  [55] = {.entry = {.count = 1, .reusable = true}}, SHIFT(107),
  [57] = {.entry = {.count = 1, .reusable = true}}, SHIFT(117),
  [59] = {.entry = {.count = 1, .reusable = true}}, SHIFT(29),
  [61] = {.entry = {.count = 1, .reusable = true}}, SHIFT(123),
  [63] = {.entry = {.count = 1, .reusable = true}}, SHIFT(127),
  [65] = {.entry = {.count = 1, .reusable = true}}, SHIFT(128),
  [67] = {.entry = {.count = 1, .reusable = true}}, SHIFT(122),
  [69] = {.entry = {.count = 1, .reusable = true}}, SHIFT(120),
  [71] = {.entry = {.count = 1, .reusable = true}}, SHIFT(126),
  [73] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__path_pattern, 1, 0, 0),
  [75] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__path_pattern, 1, 0, 0),
  [77] = {.entry = {.count = 1, .reusable = true}}, SHIFT(80),
  [79] = {.entry = {.count = 1, .reusable = true}}, SHIFT(76),
  [81] = {.entry = {.count = 1, .reusable = true}}, SHIFT(89),
  [83] = {.entry = {.count = 1, .reusable = true}}, SHIFT(92),
  [85] = {.entry = {.count = 1, .reusable = true}}, SHIFT(98),
  [87] = {.entry = {.count = 1, .reusable = true}}, SHIFT(104),
  [89] = {.entry = {.count = 1, .reusable = true}}, SHIFT(48),
  [91] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__top_level_pattern, 1, 0, 0),
  [93] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__top_level_pattern, 1, 0, 0),
  [95] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gram_pattern, 2, 0, 1),
  [97] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_gram_pattern_repeat1, 2, 0, 0),
  [99] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_gram_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(7),
  [102] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_gram_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(175),
  [105] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_gram_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(9),
  [108] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_gram_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(19),
  [111] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gram_pattern, 1, 0, 1),
  [113] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gram_pattern, 1, 0, 0),
  [115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(47),
  [117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(115),
  [119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(87),
  [121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(169),
  [123] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_node_pattern, 3, 0, 12),
  [125] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_node_pattern, 3, 0, 12),
  [127] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_node_pattern, 2, 0, 0),
  [129] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_node_pattern, 2, 0, 0),
  [131] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_labels, 1, 0, 0),
  [133] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__fenced_string, 2, 0, 9),
  [135] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__fenced_string, 2, 0, 9),
  [137] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string_literal, 1, 0, 5),
  [139] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string_literal, 1, 0, 5),
  [141] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_labels_repeat1, 2, 0, 0),
  [143] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_labels_repeat1, 2, 0, 0), SHIFT_REPEAT(142),
  [146] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_labels_repeat1, 2, 0, 0), SHIFT_REPEAT(142),
  [149] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__backticked_string, 3, 0, 17),
  [151] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__backticked_string, 3, 0, 17),
  [153] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__fenced_string_body, 3, 0, 17),
  [155] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__fenced_string_body, 3, 0, 17),
  [157] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__fenced_string_body, 2, 0, 0),
  [159] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__fenced_string_body, 2, 0, 0),
  [161] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__single_quoted_string, 3, 0, 17),
  [163] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__single_quoted_string, 3, 0, 17),
  [165] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__double_quoted_string, 3, 0, 17),
  [167] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__double_quoted_string, 3, 0, 17),
  [169] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__subject, 1, 0, 2),
  [171] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__label, 2, 0, 0),
  [173] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__label, 2, 0, 0),
  [175] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record, 3, 0, 0),
  [177] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record, 3, 0, 0),
  [179] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record, 4, 0, 0),
  [181] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record, 4, 0, 0),
  [183] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record, 2, 0, 0),
  [185] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record, 2, 0, 0),
  [187] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_identified_annotation, 2, 0, 6),
  [189] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subject_pattern, 3, 0, 12),
  [191] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subject_pattern, 3, 0, 12),
  [193] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subject_pattern, 2, 0, 0),
  [195] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subject_pattern, 2, 0, 0),
  [197] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_relationship_pattern, 3, 0, 15),
  [199] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_relationship_pattern, 3, 0, 15),
  [201] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subject_pattern, 4, 0, 16),
  [203] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subject_pattern, 4, 0, 16),
  [205] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subject_pattern, 5, 0, 20),
  [207] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subject_pattern, 5, 0, 20),
  [209] = {.entry = {.count = 1, .reusable = false}}, SHIFT(71),
  [211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(71),
  [213] = {.entry = {.count = 1, .reusable = false}}, SHIFT(73),
  [215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(73),
  [217] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_annotations, 2, 0, 0),
  [219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(175),
  [221] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__value, 1, 0, 0),
  [223] = {.entry = {.count = 1, .reusable = false}}, SHIFT(55),
  [225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(72),
  [227] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__subject, 2, 0, 10),
  [229] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__subject, 1, 0, 3),
  [231] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_annotated_pattern, 2, 0, 8),
  [233] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_annotated_pattern, 2, 0, 8),
  [235] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__scalar_value, 1, 0, 0),
  [237] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_annotations_repeat1, 2, 0, 0),
  [239] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_annotations_repeat1, 2, 0, 0), SHIFT_REPEAT(175),
  [242] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_annotations, 1, 0, 0),
  [244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(171),
  [246] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tagged_string, 5, 0, 28),
  [248] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_boolean_literal, 1, 0, 0),
  [250] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_range, 2, 0, 21),
  [252] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_range, 2, 0, 23),
  [254] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_range, 3, 0, 24),
  [256] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tagged_string, 4, 0, 26),
  [258] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tagged_string, 4, 0, 27),
  [260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14),
  [262] = {.entry = {.count = 1, .reusable = false}}, SHIFT(170),
  [264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(136),
  [266] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subject_pattern_elements, 2, 0, 0),
  [268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17),
  [270] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subject_pattern_elements, 1, 0, 0),
  [272] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__subject, 3, 0, 18),
  [274] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15),
  [276] = {.entry = {.count = 1, .reusable = false}}, SHIFT(173),
  [278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(113),
  [280] = {.entry = {.count = 1, .reusable = false}}, SHIFT_EXTRA(),
  [282] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_record_repeat1, 2, 0, 0), SHIFT_REPEAT(28),
  [285] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_record_repeat1, 2, 0, 0),
  [287] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_subject_pattern_elements_repeat1, 2, 0, 0),
  [289] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subject_pattern_elements_repeat1, 2, 0, 0), SHIFT_REPEAT(17),
  [292] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__subject, 2, 0, 11),
  [294] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_identified_annotation, 3, 0, 14),
  [296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(93),
  [298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4),
  [300] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_map, 2, 0, 0),
  [302] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__subject, 1, 0, 4),
  [304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11),
  [306] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_annotation, 5, 0, 22),
  [308] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_identified_annotation, 2, 0, 7),
  [310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16),
  [312] = {.entry = {.count = 1, .reusable = false}}, SHIFT(172),
  [314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(132),
  [316] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array, 3, 0, 0),
  [318] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__subject, 2, 0, 13),
  [320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(100),
  [322] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_map, 3, 0, 0),
  [324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(30),
  [326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(102),
  [328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12),
  [330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(28),
  [332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(45),
  [334] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array, 4, 0, 0),
  [336] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_array_repeat1, 2, 0, 0),
  [338] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_array_repeat1, 2, 0, 0), SHIFT_REPEAT(4),
  [341] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_map, 4, 0, 0),
  [343] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_map_repeat1, 2, 0, 0), SHIFT_REPEAT(30),
  [346] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_map_repeat1, 2, 0, 0),
  [348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13),
  [350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(46),
  [352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(96),
  [354] = {.entry = {.count = 1, .reusable = false}}, SHIFT(157),
  [356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(158),
  [358] = {.entry = {.count = 1, .reusable = false}}, SHIFT(159),
  [360] = {.entry = {.count = 1, .reusable = true}}, SHIFT(160),
  [362] = {.entry = {.count = 1, .reusable = false}}, SHIFT(131),
  [364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(162),
  [366] = {.entry = {.count = 1, .reusable = false}}, SHIFT(163),
  [368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(164),
  [370] = {.entry = {.count = 1, .reusable = false}}, SHIFT(40),
  [372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(140),
  [374] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_property, 3, 0, 19),
  [376] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3),
  [378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3),
  [380] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pattern_reference, 1, 0, 2),
  [382] = {.entry = {.count = 1, .reusable = false}}, SHIFT(75),
  [384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(174),
  [386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10),
  [388] = {.entry = {.count = 1, .reusable = true}}, SHIFT(49),
  [390] = {.entry = {.count = 1, .reusable = false}}, SHIFT(133),
  [392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(134),
  [394] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_map_entry, 3, 0, 19),
  [396] = {.entry = {.count = 1, .reusable = false}}, SHIFT(138),
  [398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(139),
  [400] = {.entry = {.count = 1, .reusable = false}}, SHIFT(153),
  [402] = {.entry = {.count = 1, .reusable = true}}, SHIFT(154),
  [404] = {.entry = {.count = 1, .reusable = false}}, SHIFT(155),
  [406] = {.entry = {.count = 1, .reusable = true}}, SHIFT(156),
  [408] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_left_arrow, 5, 0, 25),
  [410] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bidirectional_arrow, 2, 0, 0),
  [412] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_undirected_arrow, 4, 0, 0),
  [414] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_right_arrow, 4, 0, 0),
  [416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(129),
  [418] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_right_arrow, 2, 0, 0),
  [420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(130),
  [422] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_left_arrow, 4, 0, 0),
  [424] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bidirectional_arrow, 4, 0, 0),
  [426] = {.entry = {.count = 1, .reusable = true}}, SHIFT(39),
  [428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(108),
  [430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(44),
  [432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(109),
  [434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(53),
  [436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(110),
  [438] = {.entry = {.count = 1, .reusable = true}},  ACCEPT_INPUT(),
  [440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2),
  [442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(111),
  [444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(41),
  [446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(74),
  [448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(52),
  [450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(27),
  [452] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_undirected_arrow, 5, 0, 25),
  [454] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_right_arrow, 5, 0, 25),
  [456] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bidirectional_arrow, 5, 0, 25),
  [458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(38),
  [460] = {.entry = {.count = 1, .reusable = false}}, SHIFT(149),
  [462] = {.entry = {.count = 1, .reusable = false}}, SHIFT(176),
  [464] = {.entry = {.count = 1, .reusable = true}}, SHIFT(90),
  [466] = {.entry = {.count = 1, .reusable = false}}, SHIFT(161),
  [468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6),
  [470] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_undirected_arrow, 2, 0, 0),
  [472] = {.entry = {.count = 1, .reusable = false}}, SHIFT(150),
  [474] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_left_arrow, 2, 0, 0),
  [476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(118),
  [478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(67),
  [480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(147),
  [482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(42),
};

#ifdef __cplusplus
extern "C" {
#endif
#ifdef TREE_SITTER_HIDE_SYMBOLS
#define TS_PUBLIC
#elif defined(_WIN32)
#define TS_PUBLIC __declspec(dllexport)
#else
#define TS_PUBLIC __attribute__((visibility("default")))
#endif

TS_PUBLIC const TSLanguage *tree_sitter_gram(void) {
  static const TSLanguage language = {
    .abi_version = LANGUAGE_VERSION,
    .symbol_count = SYMBOL_COUNT,
    .alias_count = ALIAS_COUNT,
    .token_count = TOKEN_COUNT,
    .external_token_count = EXTERNAL_TOKEN_COUNT,
    .state_count = STATE_COUNT,
    .large_state_count = LARGE_STATE_COUNT,
    .production_id_count = PRODUCTION_ID_COUNT,
    .supertype_count = SUPERTYPE_COUNT,
    .field_count = FIELD_COUNT,
    .max_alias_sequence_length = MAX_ALIAS_SEQUENCE_LENGTH,
    .parse_table = &ts_parse_table[0][0],
    .small_parse_table = ts_small_parse_table,
    .small_parse_table_map = ts_small_parse_table_map,
    .parse_actions = ts_parse_actions,
    .symbol_names = ts_symbol_names,
    .field_names = ts_field_names,
    .field_map_slices = ts_field_map_slices,
    .field_map_entries = ts_field_map_entries,
    .symbol_metadata = ts_symbol_metadata,
    .public_symbol_map = ts_symbol_map,
    .alias_map = ts_non_terminal_alias_map,
    .alias_sequences = &ts_alias_sequences[0][0],
    .lex_modes = (const void*)ts_lex_modes,
    .lex_fn = ts_lex,
    .primary_state_ids = ts_primary_state_ids,
    .name = "gram",
    .max_reserved_word_set_size = 0,
    .metadata = {
      .major_version = 0,
      .minor_version = 3,
      .patch_version = 3,
    },
  };
  return &language;
}
#ifdef __cplusplus
}
#endif
